import vivisect.impapi.windows.i386 as v_w_i386
apitypes = dict(v_w_i386.apitypes)

api = {

# ntoskrnl.exe xpsp3x86 
    'ntoskrnl.main_entry':( 'int', None, 'cdecl', 'ntoskrnl.main_entry', (('int', None),) ),
    'ntoskrnl.cccaniwrite':( 'int', None, 'stdcall', 'ntoskrnl.CcCanIWrite', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.cccopyread':( 'int', None, 'stdcall', 'ntoskrnl.CcCopyRead', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.cccopywrite':( 'int', None, 'stdcall', 'ntoskrnl.CcCopyWrite', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccdeferwrite':( 'int', None, 'stdcall', 'ntoskrnl.CcDeferWrite', (('int', None), ('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccfastcopyread':( 'int', None, 'stdcall', 'ntoskrnl.CcFastCopyRead', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccfastcopywrite':( 'int', None, 'stdcall', 'ntoskrnl.CcFastCopyWrite', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccfastmdlreadwait':( 'int', None, 'cdecl', 'ntoskrnl.CcFastMdlReadWait', () ),
    'ntoskrnl.ccfastreadnotpossible':( 'int', None, 'cdecl', 'ntoskrnl.CcFastReadNotPossible', () ),
    'ntoskrnl.ccfastreadwait':( 'int', None, 'cdecl', 'ntoskrnl.CcFastReadWait', () ),
    'ntoskrnl.ccflushcache':( 'int', None, 'stdcall', 'ntoskrnl.CcFlushCache', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ccgetdirtypages':( 'int', None, 'stdcall', 'ntoskrnl.CcGetDirtyPages', (('int', None), ('void *', 'funcptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ccgetfileobjectfrombcb':( 'int', None, 'stdcall', 'ntoskrnl.CcGetFileObjectFromBcb', (('int', None),) ),
    'ntoskrnl.ccgetfileobjectfromsectionptrs':( 'int', None, 'stdcall', 'ntoskrnl.CcGetFileObjectFromSectionPtrs', (('int', None),) ),
    'ntoskrnl.ccgetflushedvaliddata':( 'int', None, 'stdcall', 'ntoskrnl.CcGetFlushedValidData', (('int', None), ('int', None)) ),
    'ntoskrnl.ccgetlsnforfileobject':( 'int', None, 'stdcall', 'ntoskrnl.CcGetLsnForFileObject', (('int', None), ('int', None)) ),
    'ntoskrnl.ccinitializecachemap':( 'int', None, 'stdcall', 'ntoskrnl.CcInitializeCacheMap', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccistheredirtydata':( 'int', None, 'stdcall', 'ntoskrnl.CcIsThereDirtyData', (('int', None),) ),
    'ntoskrnl.ccmapdata':( 'int', None, 'stdcall', 'ntoskrnl.CcMapData', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ccmdlread':( 'int', None, 'stdcall', 'ntoskrnl.CcMdlRead', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccmdlreadcomplete':( 'int', None, 'stdcall', 'ntoskrnl.CcMdlReadComplete', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ccmdlwriteabort':( 'int', None, 'stdcall', 'ntoskrnl.CcMdlWriteAbort', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ccmdlwritecomplete':( 'int', None, 'stdcall', 'ntoskrnl.CcMdlWriteComplete', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ccpinmappeddata':( 'int', None, 'stdcall', 'ntoskrnl.CcPinMappedData', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccpinread':( 'int', None, 'stdcall', 'ntoskrnl.CcPinRead', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ccpreparemdlwrite':( 'int', None, 'stdcall', 'ntoskrnl.CcPrepareMdlWrite', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccpreparepinwrite':( 'int', None, 'stdcall', 'ntoskrnl.CcPreparePinWrite', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccpurgecachesection':( 'int', None, 'thiscall', 'ntoskrnl.CcPurgeCacheSection', (('void *', 'obj'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ccremapbcb':( 'int', None, 'stdcall', 'ntoskrnl.CcRemapBcb', (('int', None),) ),
    'ntoskrnl.ccrepinbcb':( 'int', None, 'stdcall', 'ntoskrnl.CcRepinBcb', (('int', None),) ),
    'ntoskrnl.ccschedulereadahead':( 'int', None, 'stdcall', 'ntoskrnl.CcScheduleReadAhead', (('void *', 'obj'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ccsetadditionalcacheattributes':( 'int', None, 'stdcall', 'ntoskrnl.CcSetAdditionalCacheAttributes', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccsetbcbownerpointer':( 'int', None, 'stdcall', 'ntoskrnl.CcSetBcbOwnerPointer', (('int', None), ('int', None)) ),
    'ntoskrnl.ccsetdirtypagethreshold':( 'int', None, 'stdcall', 'ntoskrnl.CcSetDirtyPageThreshold', (('int', None), ('int', None)) ),
    'ntoskrnl.ccsetdirtypinneddata':( 'int', None, 'stdcall', 'ntoskrnl.CcSetDirtyPinnedData', (('int', None), ('int', None)) ),
    'ntoskrnl.ccsetfilesizes':( 'int', None, 'stdcall', 'ntoskrnl.CcSetFileSizes', (('int', None), ('int', None)) ),
    'ntoskrnl.ccsetloghandleforfile':( 'int', None, 'stdcall', 'ntoskrnl.CcSetLogHandleForFile', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccsetreadaheadgranularity':( 'int', None, 'stdcall', 'ntoskrnl.CcSetReadAheadGranularity', (('int', None), ('int', None)) ),
    'ntoskrnl.ccuninitializecachemap':( 'int', None, 'stdcall', 'ntoskrnl.CcUninitializeCacheMap', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ccunpindata':( 'int', None, 'stdcall', 'ntoskrnl.CcUnpinData', (('void *', 'obj'),) ),
    'ntoskrnl.ccunpindataforthread':( 'int', None, 'stdcall', 'ntoskrnl.CcUnpinDataForThread', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.ccunpinrepinnedbcb':( 'int', None, 'stdcall', 'ntoskrnl.CcUnpinRepinnedBcb', (('void *', 'obj'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ccwaitforcurrentlazywriteractivity':( 'int', None, 'cdecl', 'ntoskrnl.CcWaitForCurrentLazyWriterActivity', () ),
    'ntoskrnl.cczerodata':( 'int', None, 'stdcall', 'ntoskrnl.CcZeroData', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.cmregistercallback':( 'int', None, 'stdcall', 'ntoskrnl.CmRegisterCallback', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.cmunregistercallback':( 'int', None, 'stdcall', 'ntoskrnl.CmUnRegisterCallback', (('int', None), ('int', None)) ),
    'ntoskrnl.dbgbreakpoint':( 'int', None, 'cdecl', 'ntoskrnl.DbgBreakPoint', () ),
    'ntoskrnl.dbgbreakpointwithstatus':( 'int', None, 'cdecl', 'ntoskrnl.DbgBreakPointWithStatus', (('int', None),) ),
    'ntoskrnl.dbgloadimagesymbols':( 'int', None, 'stdcall', 'ntoskrnl.DbgLoadImageSymbols', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.dbgprint':( 'int', None, 'cdecl', 'ntoskrnl.DbgPrint', (('int', None),) ),
    'ntoskrnl.dbgprintex':( 'int', None, 'cdecl', 'ntoskrnl.DbgPrintEx', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.dbgprintreturncontrolc':( 'int', None, 'cdecl', 'ntoskrnl.DbgPrintReturnControlC', (('int', None),) ),
    'ntoskrnl.dbgprompt':( 'int', None, 'stdcall', 'ntoskrnl.DbgPrompt', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.dbgquerydebugfilterstate':( 'int', None, 'stdcall', 'ntoskrnl.DbgQueryDebugFilterState', (('int', None), ('int', None)) ),
    'ntoskrnl.dbgsetdebugfilterstate':( 'int', None, 'msfastcall', 'ntoskrnl.DbgSetDebugFilterState', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exacquirefastmutexunsafe':( 'int', None, 'thiscall', 'ntoskrnl.ExAcquireFastMutexUnsafe', (('void *', 'obj'),) ),
    'ntoskrnl.exacquireresourceexclusivelite':( 'int', None, 'stdcall', 'ntoskrnl.ExAcquireResourceExclusiveLite', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exacquireresourcesharedlite':( 'int', None, 'stdcall', 'ntoskrnl.ExAcquireResourceSharedLite', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exacquirerundownprotection':( 'int', None, 'thiscall', 'ntoskrnl.ExAcquireRundownProtection', (('void *', 'obj'),) ),
    'ntoskrnl.exacquirerundownprotectionex':( 'int', None, 'thiscall', 'ntoskrnl.ExAcquireRundownProtectionEx', (('void *', 'obj'),) ),
    'ntoskrnl.exacquiresharedstarveexclusive':( 'int', None, 'stdcall', 'ntoskrnl.ExAcquireSharedStarveExclusive', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exacquiresharedwaitforexclusive':( 'int', None, 'stdcall', 'ntoskrnl.ExAcquireSharedWaitForExclusive', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exallocatefrompagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExAllocateFromPagedLookasideList', (('void *', 'obj'),) ),
    'ntoskrnl.exallocatepool':( 'int', None, 'stdcall', 'ntoskrnl.ExAllocatePool', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.exallocatepoolwithquota':( 'int', None, 'stdcall', 'ntoskrnl.ExAllocatePoolWithQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.exallocatepoolwithquotatag':( 'int', None, 'stdcall', 'ntoskrnl.ExAllocatePoolWithQuotaTag', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exallocatepoolwithtag':( 'int', None, 'cdecl', 'ntoskrnl.ExAllocatePoolWithTag', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exallocatepoolwithtagpriority':( 'int', None, 'stdcall', 'ntoskrnl.ExAllocatePoolWithTagPriority', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exconvertexclusivetosharedlite':( 'int', None, 'stdcall', 'ntoskrnl.ExConvertExclusiveToSharedLite', (('int', None),) ),
    'ntoskrnl.excreatecallback':( 'int', None, 'stdcall', 'ntoskrnl.ExCreateCallback', (('int', None), ('void *', 'ptr'), ('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exdeletenpagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExDeleteNPagedLookasideList', (('void *', 'obj'),) ),
    'ntoskrnl.exdeletepagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExDeletePagedLookasideList', (('void *', 'obj'),) ),
    'ntoskrnl.exdeleteresourcelite':( 'int', None, 'stdcall', 'ntoskrnl.ExDeleteResourceLite', (('int', None),) ),
    'ntoskrnl.exdesktopobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.ExDesktopObjectType', () ),
    'ntoskrnl.exdisableresourceboostlite':( 'int', None, 'stdcall', 'ntoskrnl.ExDisableResourceBoostLite', (('int', None),) ),
    'ntoskrnl.exenumhandletable':( 'int', None, 'stdcall', 'ntoskrnl.ExEnumHandleTable', (('void *', 'obj'), ('void *', 'funcptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exeventobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.ExEventObjectType', () ),
    'ntoskrnl.exextendzone':( 'int', None, 'stdcall', 'ntoskrnl.ExExtendZone', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exfreepool':( 'int', None, 'stdcall', 'ntoskrnl.ExFreePool', (('int', None),) ),
    'ntoskrnl.exfreepoolwithtag':( 'int', None, 'stdcall', 'ntoskrnl.ExFreePoolWithTag', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exfreetopagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExFreeToPagedLookasideList', (('int', None), ('int', None)) ),
    'ntoskrnl.exgetcurrentprocessorcounts':( 'int', None, 'stdcall', 'ntoskrnl.ExGetCurrentProcessorCounts', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exgetcurrentprocessorcpuusage':( 'int', None, 'stdcall', 'ntoskrnl.ExGetCurrentProcessorCpuUsage', (('int', None),) ),
    'ntoskrnl.exgetexclusivewaitercount':( 'int', None, 'stdcall', 'ntoskrnl.ExGetExclusiveWaiterCount', (('int', None),) ),
    'ntoskrnl.exgetpreviousmode':( 'int', None, 'cdecl', 'ntoskrnl.ExGetPreviousMode', () ),
    'ntoskrnl.exgetsharedwaitercount':( 'int', None, 'stdcall', 'ntoskrnl.ExGetSharedWaiterCount', (('int', None),) ),
    'ntoskrnl.exinitializenpagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExInitializeNPagedLookasideList', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinitializepagedlookasidelist':( 'int', None, 'stdcall', 'ntoskrnl.ExInitializePagedLookasideList', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinitializeresourcelite':( 'int', None, 'stdcall', 'ntoskrnl.ExInitializeResourceLite', (('int', None),) ),
    'ntoskrnl.exinitializerundownprotection':( 'int', None, 'thiscall', 'ntoskrnl.ExInitializeRundownProtection', (('void *', 'obj'),) ),
    'ntoskrnl.exinitializezone':( 'int', None, 'stdcall', 'ntoskrnl.ExInitializeZone', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedaddlargeinteger':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedAddLargeInteger', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedaddlargestatistic':( 'int', None, 'thiscall', 'ntoskrnl.ExInterlockedAddLargeStatistic', (('void *', 'obj'),) ),
    'ntoskrnl.exinterlockedaddulong':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedAddUlong', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedcompareexchange64':( 'int', None, 'msfastcall', 'ntoskrnl.ExInterlockedCompareExchange64', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockeddecrementlong':( 'int', None, 'cdecl', 'ntoskrnl.ExInterlockedDecrementLong', (('int', None),) ),
    'ntoskrnl.exinterlockedexchangeulong':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedExchangeUlong', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedextendzone':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedExtendZone', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedflushslist':( 'int', None, 'thiscall', 'ntoskrnl.ExInterlockedFlushSList', (('void *', 'obj'),) ),
    'ntoskrnl.exinterlockedincrementlong':( 'int', None, 'cdecl', 'ntoskrnl.ExInterlockedIncrementLong', (('int', None),) ),
    'ntoskrnl.exinterlockedinsertheadlist':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedInsertHeadList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedinserttaillist':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedInsertTailList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedpopentrylist':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedPopEntryList', (('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedpopentryslist':( 'int', None, 'thiscall', 'ntoskrnl.ExInterlockedPopEntrySList', (('void *', 'obj'),) ),
    'ntoskrnl.exinterlockedpushentrylist':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedPushEntryList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedpushentryslist':( 'int', None, 'msfastcall', 'ntoskrnl.ExInterlockedPushEntrySList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exinterlockedremoveheadlist':( 'int', None, 'stdcall', 'ntoskrnl.ExInterlockedRemoveHeadList', (('int', None), ('int', None)) ),
    'ntoskrnl.exisprocessorfeaturepresent':( 'int', None, 'stdcall', 'ntoskrnl.ExIsProcessorFeaturePresent', (('int', None),) ),
    'ntoskrnl.exisresourceacquiredexclusivelite':( 'int', None, 'stdcall', 'ntoskrnl.ExIsResourceAcquiredExclusiveLite', (('int', None),) ),
    'ntoskrnl.exisresourceacquiredsharedlite':( 'int', None, 'stdcall', 'ntoskrnl.ExIsResourceAcquiredSharedLite', (('int', None),) ),
    'ntoskrnl.exlocaltimetosystemtime':( 'int', None, 'stdcall', 'ntoskrnl.ExLocalTimeToSystemTime', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.exnotifycallback':( 'int', None, 'stdcall', 'ntoskrnl.ExNotifyCallback', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exquerypoolblocksize':( 'int', None, 'stdcall', 'ntoskrnl.ExQueryPoolBlockSize', (('int', None), ('int', None)) ),
    'ntoskrnl.exqueueworkitem':( 'int', None, 'stdcall', 'ntoskrnl.ExQueueWorkItem', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exraiseaccessviolation':( 'int', None, 'cdecl', 'ntoskrnl.ExRaiseAccessViolation', () ),
    'ntoskrnl.exraisedatatypemisalignment':( 'int', None, 'cdecl', 'ntoskrnl.ExRaiseDatatypeMisalignment', () ),
    'ntoskrnl.exraiseexception':( 'int', None, 'cdecl', 'ntoskrnl.ExRaiseException', (('void *', 'ptr'),) ),
    'ntoskrnl.exraiseharderror':( 'int', None, 'msfastcall', 'ntoskrnl.ExRaiseHardError', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.exraisestatus':( 'int', None, 'cdecl', 'ntoskrnl.ExRaiseStatus', (('int', None),) ),
    'ntoskrnl.exreinitializerundownprotection':( 'int', None, 'thiscall', 'ntoskrnl.ExReInitializeRundownProtection', (('void *', 'obj'),) ),
    'ntoskrnl.exregistercallback':( 'int', None, 'stdcall', 'ntoskrnl.ExRegisterCallback', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.exreinitializeresourcelite':( 'int', None, 'stdcall', 'ntoskrnl.ExReinitializeResourceLite', (('int', None),) ),
    'ntoskrnl.exreleasefastmutexunsafe':( 'int', None, 'thiscall', 'ntoskrnl.ExReleaseFastMutexUnsafe', (('void *', 'obj'),) ),
    'ntoskrnl.exreleaseresourceforthreadlite':( 'int', None, 'stdcall', 'ntoskrnl.ExReleaseResourceForThreadLite', (('int', None), ('int', None)) ),
    'ntoskrnl.exreleaseresourcelite':( 'int', None, 'thiscall', 'ntoskrnl.ExReleaseResourceLite', (('void *', 'obj'),) ),
    'ntoskrnl.exreleaserundownprotection':( 'int', None, 'thiscall', 'ntoskrnl.ExReleaseRundownProtection', (('void *', 'obj'),) ),
    'ntoskrnl.exreleaserundownprotectionex':( 'int', None, 'thiscall', 'ntoskrnl.ExReleaseRundownProtectionEx', (('void *', 'obj'),) ),
    'ntoskrnl.exrundowncompleted':( 'int', None, 'thiscall', 'ntoskrnl.ExRundownCompleted', (('void *', 'obj'),) ),
    'ntoskrnl.exsemaphoreobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.ExSemaphoreObjectType', () ),
    'ntoskrnl.exsetresourceownerpointer':( 'int', None, 'stdcall', 'ntoskrnl.ExSetResourceOwnerPointer', (('int', None), ('int', None)) ),
    'ntoskrnl.exsettimerresolution':( 'int', None, 'stdcall', 'ntoskrnl.ExSetTimerResolution', (('int', None), ('int', None)) ),
    'ntoskrnl.exsystemexceptionfilter':( 'int', None, 'cdecl', 'ntoskrnl.ExSystemExceptionFilter', () ),
    'ntoskrnl.exsystemtimetolocaltime':( 'int', None, 'stdcall', 'ntoskrnl.ExSystemTimeToLocalTime', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.exunregistercallback':( 'int', None, 'stdcall', 'ntoskrnl.ExUnregisterCallback', (('void *', 'ptr'),) ),
    'ntoskrnl.exuuidcreate':( 'int', None, 'stdcall', 'ntoskrnl.ExUuidCreate', (('void *', 'ptr'),) ),
    'ntoskrnl.exverifysuite':( 'int', None, 'stdcall', 'ntoskrnl.ExVerifySuite', (('int', None),) ),
    'ntoskrnl.exwaitforrundownprotectionrelease':( 'int', None, 'thiscall', 'ntoskrnl.ExWaitForRundownProtectionRelease', (('void *', 'obj'),) ),
    'ntoskrnl.exwindowstationobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.ExWindowStationObjectType', () ),
    'ntoskrnl.exfacquirepushlockexclusive':( 'int', None, 'thiscall', 'ntoskrnl.ExfAcquirePushLockExclusive', (('void *', 'obj'),) ),
    'ntoskrnl.exfacquirepushlockshared':( 'int', None, 'thiscall', 'ntoskrnl.ExfAcquirePushLockShared', (('void *', 'obj'),) ),
    'ntoskrnl.exfinterlockedaddulong':( 'int', None, 'thiscall', 'ntoskrnl.ExfInterlockedAddUlong', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.exfinterlockedcompareexchange64':( 'int', None, 'msfastcall', 'ntoskrnl.ExfInterlockedCompareExchange64', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.exfinterlockedinsertheadlist':( 'int', None, 'msfastcall', 'ntoskrnl.ExfInterlockedInsertHeadList', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exfinterlockedinserttaillist':( 'int', None, 'msfastcall', 'ntoskrnl.ExfInterlockedInsertTailList', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.exfinterlockedpopentrylist':( 'int', None, 'thiscall', 'ntoskrnl.ExfInterlockedPopEntryList', (('void *', 'obj'),) ),
    'ntoskrnl.exfinterlockedpushentrylist':( 'int', None, 'msfastcall', 'ntoskrnl.ExfInterlockedPushEntryList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.exfinterlockedremoveheadlist':( 'int', None, 'thiscall', 'ntoskrnl.ExfInterlockedRemoveHeadList', (('void *', 'obj'),) ),
    'ntoskrnl.exfreleasepushlock':( 'int', None, 'thiscall', 'ntoskrnl.ExfReleasePushLock', (('void *', 'obj'),) ),
    'ntoskrnl.exfi386interlockeddecrementlong':( 'int', None, 'thiscall', 'ntoskrnl.Exfi386InterlockedDecrementLong', (('void *', 'obj'),) ),
    'ntoskrnl.exfi386interlockedexchangeulong':( 'int', None, 'thiscall', 'ntoskrnl.Exfi386InterlockedExchangeUlong', (('void *', 'obj'),) ),
    'ntoskrnl.exfi386interlockedincrementlong':( 'int', None, 'thiscall', 'ntoskrnl.Exfi386InterlockedIncrementLong', (('void *', 'obj'),) ),
    'ntoskrnl.exi386interlockeddecrementlong':( 'int', None, 'cdecl', 'ntoskrnl.Exi386InterlockedDecrementLong', (('int', None),) ),
    'ntoskrnl.exi386interlockedexchangeulong':( 'int', None, 'stdcall', 'ntoskrnl.Exi386InterlockedExchangeUlong', (('int', None), ('int', None)) ),
    'ntoskrnl.exi386interlockedincrementlong':( 'int', None, 'cdecl', 'ntoskrnl.Exi386InterlockedIncrementLong', (('int', None),) ),
    'ntoskrnl.fsrtlacquirefileexclusive':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAcquireFileExclusive', (('int', None),) ),
    'ntoskrnl.fsrtladdlargemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAddLargeMcbEntry', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtladdmcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAddMcbEntry', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtladdtotunnelcache':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAddToTunnelCache', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlallocatefilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAllocateFileLock', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlallocatepool':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAllocatePool', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlallocatepoolwithquota':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAllocatePoolWithQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlallocatepoolwithquotatag':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAllocatePoolWithQuotaTag', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlallocatepoolwithtag':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAllocatePoolWithTag', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtlallocateresource':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlAllocateResource', () ),
    'ntoskrnl.fsrtlarenamesequal':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlAreNamesEqual', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlbalancereads':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlBalanceReads', (('int', None),) ),
    'ntoskrnl.fsrtlchecklockforreadaccess':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCheckLockForReadAccess', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlchecklockforwriteaccess':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCheckLockForWriteAccess', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlcheckoplock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCheckOplock', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'funcptr')) ),
    'ntoskrnl.fsrtlcopyread':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCopyRead', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlcopywrite':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCopyWrite', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlcreatesectionfordatascan':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCreateSectionForDataScan', (('int', None), ('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlcurrentbatchoplock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlCurrentBatchOplock', (('int', None),) ),
    'ntoskrnl.fsrtldeletekeyfromtunnelcache':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDeleteKeyFromTunnelCache', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtldeletetunnelcache':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDeleteTunnelCache', (('int', None),) ),
    'ntoskrnl.fsrtlderegisteruncprovider':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDeregisterUncProvider', (('int', None),) ),
    'ntoskrnl.fsrtldissectdbcs':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDissectDbcs', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtldissectname':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDissectName', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtldoesdbcscontainwildcards':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDoesDbcsContainWildCards', (('void *', 'ptr'),) ),
    'ntoskrnl.fsrtldoesnamecontainwildcards':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlDoesNameContainWildCards', (('void *', 'ptr'),) ),
    'ntoskrnl.fsrtlfastchecklockforread':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFastCheckLockForRead', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfastchecklockforwrite':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFastCheckLockForWrite', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfastunlockall':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFastUnlockAll', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfastunlockallbykey':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFastUnlockAllByKey', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfastunlocksingle':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFastUnlockSingle', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfindintunnelcache':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFindInTunnelCache', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlfreefilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlFreeFileLock', (('int', None),) ),
    'ntoskrnl.fsrtlgetfilesize':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlGetFileSize', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlgetnextfilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlGetNextFileLock', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlgetnextlargemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlGetNextLargeMcbEntry', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlgetnextmcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlGetNextMcbEntry', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlincrementccfastreadnowait':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlIncrementCcFastReadNoWait', () ),
    'ntoskrnl.fsrtlincrementccfastreadnotpossible':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlIncrementCcFastReadNotPossible', () ),
    'ntoskrnl.fsrtlincrementccfastreadresourcemiss':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlIncrementCcFastReadResourceMiss', () ),
    'ntoskrnl.fsrtlincrementccfastreadwait':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlIncrementCcFastReadWait', () ),
    'ntoskrnl.fsrtlinitializefilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInitializeFileLock', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlinitializelargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInitializeLargeMcb', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlinitializemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInitializeMcb', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlinitializeoplock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInitializeOplock', (('int', None),) ),
    'ntoskrnl.fsrtlinitializetunnelcache':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInitializeTunnelCache', (('int', None),) ),
    'ntoskrnl.fsrtlinsertperfileobjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInsertPerFileObjectContext', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlinsertperstreamcontext':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlInsertPerStreamContext', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlisdbcsinexpression':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsDbcsInExpression', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlisfatdbcslegal':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsFatDbcsLegal', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlishpfsdbcslegal':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsHpfsDbcsLegal', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlisnameinexpression':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsNameInExpression', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlisntstatusexpected':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsNtstatusExpected', (('int', None),) ),
    'ntoskrnl.fsrtlispagingfile':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsPagingFile', (('int', None),) ),
    'ntoskrnl.fsrtlistotaldevicefailure':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlIsTotalDeviceFailure', (('int', None),) ),
    'ntoskrnl.fsrtllegalansicharacterarray':( 'int', None, 'cdecl', 'ntoskrnl.FsRtlLegalAnsiCharacterArray', () ),
    'ntoskrnl.fsrtllookuplargemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupLargeMcbEntry', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtllookuplastlargemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupLastLargeMcbEntry', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtllookuplastlargemcbentryandindex':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupLastLargeMcbEntryAndIndex', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtllookuplastmcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupLastMcbEntry', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtllookupmcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupMcbEntry', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtllookupperfileobjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupPerFileObjectContext', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtllookupperstreamcontextinternal':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlLookupPerStreamContextInternal', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlmdlread':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlRead', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlmdlreadcomplete':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlReadComplete', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlmdlreadcompletedev':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlReadCompleteDev', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtlmdlreaddev':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlReadDev', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlmdlwritecomplete':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlWriteComplete', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlmdlwritecompletedev':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlMdlWriteCompleteDev', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtlnormalizentstatus':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNormalizeNtstatus', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifychangedirectory':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyChangeDirectory', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.fsrtlnotifycleanup':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyCleanup', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyfilterchangedirectory':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyFilterChangeDirectory', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyfilterreportchange':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyFilterReportChange', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyfullchangedirectory':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyFullChangeDirectory', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyfullreportchange':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyFullReportChange', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyinitializesync':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyInitializeSync', (('int', None),) ),
    'ntoskrnl.fsrtlnotifyreportchange':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyReportChange', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnotifyuninitializesync':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyUninitializeSync', (('int', None),) ),
    'ntoskrnl.fsrtlnotifyvolumeevent':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNotifyVolumeEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlnumberofrunsinlargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNumberOfRunsInLargeMcb', (('int', None),) ),
    'ntoskrnl.fsrtlnumberofrunsinmcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlNumberOfRunsInMcb', (('int', None),) ),
    'ntoskrnl.fsrtloplockfsctrl':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlOplockFsctrl', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtloplockisfastiopossible':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlOplockIsFastIoPossible', (('int', None),) ),
    'ntoskrnl.fsrtlpostpagingfilestackoverflow':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlPostPagingFileStackOverflow', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlpoststackoverflow':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlPostStackOverflow', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlpreparemdlwrite':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlPrepareMdlWrite', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlpreparemdlwritedev':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlPrepareMdlWriteDev', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlprivatelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlPrivateLock', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlprocessfilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlProcessFileLock', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlregisterfilesystemfiltercallbacks':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRegisterFileSystemFilterCallbacks', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlregisteruncprovider':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRegisterUncProvider', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.fsrtlreleasefile':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlReleaseFile', (('int', None),) ),
    'ntoskrnl.fsrtlremovelargemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRemoveLargeMcbEntry', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlremovemcbentry':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRemoveMcbEntry', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlremoveperfileobjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRemovePerFileObjectContext', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlremoveperstreamcontext':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlRemovePerStreamContext', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlresetlargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlResetLargeMcb', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlsplitlargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlSplitLargeMcb', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlsyncvolumes':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlSyncVolumes', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtlteardownperstreamcontexts':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlTeardownPerStreamContexts', (('int', None),) ),
    'ntoskrnl.fsrtltruncatelargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlTruncateLargeMcb', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.fsrtltruncatemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlTruncateMcb', (('int', None), ('int', None)) ),
    'ntoskrnl.fsrtluninitializefilelock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlUninitializeFileLock', (('int', None),) ),
    'ntoskrnl.fsrtluninitializelargemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlUninitializeLargeMcb', (('int', None),) ),
    'ntoskrnl.fsrtluninitializemcb':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlUninitializeMcb', (('int', None),) ),
    'ntoskrnl.fsrtluninitializeoplock':( 'int', None, 'stdcall', 'ntoskrnl.FsRtlUninitializeOplock', (('int', None),) ),
    'ntoskrnl.haldispatchtable':( 'int', None, 'bfastcall', 'ntoskrnl.HalDispatchTable', (('int', None),) ),
    'ntoskrnl.halexaminembr':( 'int', None, 'msfastcall', 'ntoskrnl.HalExamineMBR', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.halprivatedispatchtable':( 'int', None, 'bfastcall', 'ntoskrnl.HalPrivateDispatchTable', (('int', None),) ),
    'ntoskrnl.headlessdispatch':( 'int', None, 'stdcall', 'ntoskrnl.HeadlessDispatch', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.inbvacquiredisplayownership':( 'int', None, 'cdecl', 'ntoskrnl.InbvAcquireDisplayOwnership', () ),
    'ntoskrnl.inbvcheckdisplayownership':( 'int', None, 'cdecl', 'ntoskrnl.InbvCheckDisplayOwnership', () ),
    'ntoskrnl.inbvdisplaystring':( 'int', None, 'stdcall', 'ntoskrnl.InbvDisplayString', (('void *', 'ptr'),) ),
    'ntoskrnl.inbvenablebootdriver':( 'int', None, 'stdcall', 'ntoskrnl.InbvEnableBootDriver', (('int', None),) ),
    'ntoskrnl.inbvenabledisplaystring':( 'int', None, 'stdcall', 'ntoskrnl.InbvEnableDisplayString', (('int', None),) ),
    'ntoskrnl.inbvinstalldisplaystringfilter':( 'int', None, 'stdcall', 'ntoskrnl.InbvInstallDisplayStringFilter', (('int', None),) ),
    'ntoskrnl.inbvisbootdriverinstalled':( 'int', None, 'cdecl', 'ntoskrnl.InbvIsBootDriverInstalled', () ),
    'ntoskrnl.inbvnotifydisplayownershiplost':( 'int', None, 'stdcall', 'ntoskrnl.InbvNotifyDisplayOwnershipLost', (('int', None),) ),
    'ntoskrnl.inbvresetdisplay':( 'int', None, 'cdecl', 'ntoskrnl.InbvResetDisplay', () ),
    'ntoskrnl.inbvsetscrollregion':( 'int', None, 'cdecl', 'ntoskrnl.InbvSetScrollRegion', () ),
    'ntoskrnl.inbvsettextcolor':( 'int', None, 'stdcall', 'ntoskrnl.InbvSetTextColor', (('int', None),) ),
    'ntoskrnl.inbvsolidcolorfill':( 'int', None, 'stdcall', 'ntoskrnl.InbvSolidColorFill', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.initsafebootmode':( 'int', None, 'cdecl', 'ntoskrnl.InitSafeBootMode', () ),
    'ntoskrnl.interlockedcompareexchange':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedCompareExchange', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.interlockeddecrement':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedDecrement', (('void *', 'obj'),) ),
    'ntoskrnl.interlockedexchange':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedExchange', (('void *', 'obj'),) ),
    'ntoskrnl.interlockedexchangeadd':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedExchangeAdd', (('void *', 'obj'),) ),
    'ntoskrnl.interlockedincrement':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedIncrement', (('void *', 'obj'),) ),
    'ntoskrnl.interlockedpopentryslist':( 'int', None, 'thiscall', 'ntoskrnl.InterlockedPopEntrySList', (('void *', 'obj'),) ),
    'ntoskrnl.interlockedpushentryslist':( 'int', None, 'msfastcall', 'ntoskrnl.InterlockedPushEntrySList', (('int', None), ('int', None)) ),
    'ntoskrnl.ioacquirecancelspinlock':( 'int', None, 'stdcall', 'ntoskrnl.IoAcquireCancelSpinLock', (('void *', 'ptr'),) ),
    'ntoskrnl.ioacquireremovelockex':( 'int', None, 'stdcall', 'ntoskrnl.IoAcquireRemoveLockEx', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioacquirevpbspinlock':( 'int', None, 'stdcall', 'ntoskrnl.IoAcquireVpbSpinLock', (('void *', 'ptr'),) ),
    'ntoskrnl.ioadapterobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.IoAdapterObjectType', () ),
    'ntoskrnl.ioallocateadapterchannel':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateAdapterChannel', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioallocatecontroller':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateController', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'ntoskrnl.ioallocatedriverobjectextension':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateDriverObjectExtension', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ioallocateerrorlogentry':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateErrorLogEntry', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.ioallocateirp':( 'int', None, 'cdecl', 'ntoskrnl.IoAllocateIrp', () ),
    'ntoskrnl.ioallocatemdl':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateMdl', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioallocateworkitem':( 'int', None, 'stdcall', 'ntoskrnl.IoAllocateWorkItem', (('int', None),) ),
    'ntoskrnl.ioassigndriveletters':( 'int', None, 'msfastcall', 'ntoskrnl.IoAssignDriveLetters', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ioassignresources':( 'int', None, 'stdcall', 'ntoskrnl.IoAssignResources', (('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ioattachdevice':( 'int', None, 'stdcall', 'ntoskrnl.IoAttachDevice', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioattachdevicebypointer':( 'int', None, 'stdcall', 'ntoskrnl.IoAttachDeviceByPointer', (('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ioattachdevicetodevicestack':( 'int', None, 'stdcall', 'ntoskrnl.IoAttachDeviceToDeviceStack', (('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ioattachdevicetodevicestacksafe':( 'int', None, 'stdcall', 'ntoskrnl.IoAttachDeviceToDeviceStackSafe', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iobuildasynchronousfsdrequest':( 'int', None, 'stdcall', 'ntoskrnl.IoBuildAsynchronousFsdRequest', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.iobuilddeviceiocontrolrequest':( 'int', None, 'stdcall', 'ntoskrnl.IoBuildDeviceIoControlRequest', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iobuildpartialmdl':( 'int', None, 'stdcall', 'ntoskrnl.IoBuildPartialMdl', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iobuildsynchronousfsdrequest':( 'int', None, 'stdcall', 'ntoskrnl.IoBuildSynchronousFsdRequest', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iocalldriver':( 'int', None, 'stdcall', 'ntoskrnl.IoCallDriver', (('int', None), ('int', None)) ),
    'ntoskrnl.iocancelfileopen':( 'int', None, 'stdcall', 'ntoskrnl.IoCancelFileOpen', (('int', None), ('int', None)) ),
    'ntoskrnl.iocancelirp':( 'int', None, 'thiscall', 'ntoskrnl.IoCancelIrp', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iocheckdesiredaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckDesiredAccess', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.iocheckeabuffervalidity':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckEaBufferValidity', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iocheckfunctionaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckFunctionAccess', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocheckquerysetfileinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckQuerySetFileInformation', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocheckquerysetvolumeinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckQuerySetVolumeInformation', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocheckquotabuffervalidity':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckQuotaBufferValidity', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iocheckshareaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoCheckShareAccess', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocompleterequest':( 'int', None, 'stdcall', 'ntoskrnl.IoCompleteRequest', (('int', None), ('int', None)) ),
    'ntoskrnl.ioconnectinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.IoConnectInterrupt', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocreatecontroller':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateController', (('void *', 'ptr'),) ),
    'ntoskrnl.iocreatedevice':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateDevice', (('void *', 'obj'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iocreatedisk':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateDisk', (('int', None), ('int', None)) ),
    'ntoskrnl.iocreatedriver':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateDriver', (('void *', 'ptr'), ('void *', 'funcptr')) ),
    'ntoskrnl.iocreatefile':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateFile', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.iocreatefilespecifydeviceobjecthint':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateFileSpecifyDeviceObjectHint', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocreatenotificationevent':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateNotificationEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.iocreatestreamfileobject':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateStreamFileObject', (('int', None), ('int', None)) ),
    'ntoskrnl.iocreatestreamfileobjectex':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateStreamFileObjectEx', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocreatestreamfileobjectlite':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateStreamFileObjectLite', (('int', None), ('int', None)) ),
    'ntoskrnl.iocreatesymboliclink':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateSymbolicLink', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iocreatesynchronizationevent':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateSynchronizationEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.iocreateunprotectedsymboliclink':( 'int', None, 'stdcall', 'ntoskrnl.IoCreateUnprotectedSymbolicLink', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iocsqinitialize':( 'int', None, 'stdcall', 'ntoskrnl.IoCsqInitialize', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocsqinsertirp':( 'int', None, 'stdcall', 'ntoskrnl.IoCsqInsertIrp', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iocsqremoveirp':( 'int', None, 'stdcall', 'ntoskrnl.IoCsqRemoveIrp', (('int', None), ('int', None)) ),
    'ntoskrnl.iocsqremovenextirp':( 'int', None, 'stdcall', 'ntoskrnl.IoCsqRemoveNextIrp', (('int', None), ('int', None)) ),
    'ntoskrnl.iodeletecontroller':( 'int', None, 'stdcall', 'ntoskrnl.IoDeleteController', (('void *', 'obj'),) ),
    'ntoskrnl.iodeletedevice':( 'int', None, 'stdcall', 'ntoskrnl.IoDeleteDevice', (('void *', 'obj'),) ),
    'ntoskrnl.iodeletedriver':( 'int', None, 'stdcall', 'ntoskrnl.IoDeleteDriver', (('void *', 'obj'),) ),
    'ntoskrnl.iodeletesymboliclink':( 'int', None, 'stdcall', 'ntoskrnl.IoDeleteSymbolicLink', (('void *', 'ptr'),) ),
    'ntoskrnl.iodetachdevice':( 'int', None, 'stdcall', 'ntoskrnl.IoDetachDevice', (('void *', 'obj'),) ),
    'ntoskrnl.iodevicehandlerobjectsize':( 'int', None, 'cdecl', 'ntoskrnl.IoDeviceHandlerObjectSize', () ),
    'ntoskrnl.iodevicehandlerobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.IoDeviceHandlerObjectType', () ),
    'ntoskrnl.iodeviceobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.IoDeviceObjectType', () ),
    'ntoskrnl.iodisconnectinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.IoDisconnectInterrupt', (('void *', 'ptr'),) ),
    'ntoskrnl.iodriverobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.IoDriverObjectType', () ),
    'ntoskrnl.ioenqueueirp':( 'int', None, 'stdcall', 'ntoskrnl.IoEnqueueIrp', (('int', None),) ),
    'ntoskrnl.ioenumeratedeviceobjectlist':( 'int', None, 'stdcall', 'ntoskrnl.IoEnumerateDeviceObjectList', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioenumerateregisteredfilterslist':( 'int', None, 'stdcall', 'ntoskrnl.IoEnumerateRegisteredFiltersList', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iofastquerynetworkattributes':( 'int', None, 'stdcall', 'ntoskrnl.IoFastQueryNetworkAttributes', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iofileobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.IoFileObjectType', () ),
    'ntoskrnl.ioforwardandcatchirp':( 'int', None, 'stdcall', 'ntoskrnl.IoForwardAndCatchIrp', (('int', None), ('int', None)) ),
    'ntoskrnl.ioforwardirpsynchronously':( 'int', None, 'stdcall', 'ntoskrnl.IoForwardIrpSynchronously', (('int', None), ('int', None)) ),
    'ntoskrnl.iofreecontroller':( 'int', None, 'stdcall', 'ntoskrnl.IoFreeController', (('int', None),) ),
    'ntoskrnl.iofreeerrorlogentry':( 'int', None, 'stdcall', 'ntoskrnl.IoFreeErrorLogEntry', (('void *', 'ptr'),) ),
    'ntoskrnl.iofreeirp':( 'int', None, 'cdecl', 'ntoskrnl.IoFreeIrp', () ),
    'ntoskrnl.iofreemdl':( 'int', None, 'stdcall', 'ntoskrnl.IoFreeMdl', (('int', None),) ),
    'ntoskrnl.iofreeworkitem':( 'int', None, 'stdcall', 'ntoskrnl.IoFreeWorkItem', (('void *', 'ptr'),) ),
    'ntoskrnl.iogetattacheddevice':( 'int', None, 'stdcall', 'ntoskrnl.IoGetAttachedDevice', (('int', None),) ),
    'ntoskrnl.iogetattacheddevicereference':( 'int', None, 'stdcall', 'ntoskrnl.IoGetAttachedDeviceReference', (('int', None),) ),
    'ntoskrnl.iogetbasefilesystemdeviceobject':( 'int', None, 'stdcall', 'ntoskrnl.IoGetBaseFileSystemDeviceObject', (('int', None),) ),
    'ntoskrnl.iogetbootdiskinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoGetBootDiskInformation', (('int', None), ('int', None)) ),
    'ntoskrnl.iogetconfigurationinformation':( 'int', None, 'cdecl', 'ntoskrnl.IoGetConfigurationInformation', () ),
    'ntoskrnl.iogetcurrentprocess':( 'int', None, 'cdecl', 'ntoskrnl.IoGetCurrentProcess', () ),
    'ntoskrnl.iogetdeviceattachmentbaseref':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceAttachmentBaseRef', (('int', None),) ),
    'ntoskrnl.iogetdeviceinterfacealias':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceInterfaceAlias', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iogetdeviceinterfaces':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceInterfaces', (('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iogetdeviceobjectpointer':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceObjectPointer', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iogetdeviceproperty':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceProperty', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iogetdevicetoverify':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDeviceToVerify', (('int', None),) ),
    'ntoskrnl.iogetdiskdeviceobject':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDiskDeviceObject', (('int', None), ('int', None)) ),
    'ntoskrnl.iogetdmaadapter':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDmaAdapter', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iogetdriverobjectextension':( 'int', None, 'stdcall', 'ntoskrnl.IoGetDriverObjectExtension', (('int', None), ('int', None)) ),
    'ntoskrnl.iogetfileobjectgenericmapping':( 'int', None, 'cdecl', 'ntoskrnl.IoGetFileObjectGenericMapping', () ),
    'ntoskrnl.iogetinitialstack':( 'int', None, 'cdecl', 'ntoskrnl.IoGetInitialStack', () ),
    'ntoskrnl.iogetlowerdeviceobject':( 'int', None, 'stdcall', 'ntoskrnl.IoGetLowerDeviceObject', (('int', None),) ),
    'ntoskrnl.iogetrelateddeviceobject':( 'int', None, 'stdcall', 'ntoskrnl.IoGetRelatedDeviceObject', (('int', None),) ),
    'ntoskrnl.iogetrequestorprocess':( 'int', None, 'stdcall', 'ntoskrnl.IoGetRequestorProcess', (('int', None),) ),
    'ntoskrnl.iogetrequestorprocessid':( 'int', None, 'stdcall', 'ntoskrnl.IoGetRequestorProcessId', (('int', None),) ),
    'ntoskrnl.iogetrequestorsessionid':( 'int', None, 'stdcall', 'ntoskrnl.IoGetRequestorSessionId', (('int', None), ('int', None)) ),
    'ntoskrnl.iogetstacklimits':( 'int', None, 'stdcall', 'ntoskrnl.IoGetStackLimits', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iogettoplevelirp':( 'int', None, 'cdecl', 'ntoskrnl.IoGetTopLevelIrp', () ),
    'ntoskrnl.ioinitializecrashdump':( 'int', None, 'thiscall', 'ntoskrnl.IoInitializeCrashDump', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.ioinitializeirp':( 'int', None, 'stdcall', 'ntoskrnl.IoInitializeIrp', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioinitializeremovelockex':( 'int', None, 'stdcall', 'ntoskrnl.IoInitializeRemoveLockEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioinitializetimer':( 'int', None, 'stdcall', 'ntoskrnl.IoInitializeTimer', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioinvalidatedevicerelations':( 'int', None, 'stdcall', 'ntoskrnl.IoInvalidateDeviceRelations', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.ioinvalidatedevicestate':( 'int', None, 'stdcall', 'ntoskrnl.IoInvalidateDeviceState', (('void *', 'obj'),) ),
    'ntoskrnl.ioisfileoriginremote':( 'int', None, 'stdcall', 'ntoskrnl.IoIsFileOriginRemote', (('int', None),) ),
    'ntoskrnl.ioisoperationsynchronous':( 'int', None, 'stdcall', 'ntoskrnl.IoIsOperationSynchronous', (('int', None),) ),
    'ntoskrnl.ioissystemthread':( 'int', None, 'stdcall', 'ntoskrnl.IoIsSystemThread', (('int', None),) ),
    'ntoskrnl.ioisvalidnamegraftingbuffer':( 'int', None, 'stdcall', 'ntoskrnl.IoIsValidNameGraftingBuffer', (('int', None), ('int', None)) ),
    'ntoskrnl.ioiswdmversionavailable':( 'int', None, 'stdcall', 'ntoskrnl.IoIsWdmVersionAvailable', (('int', None), ('int', None)) ),
    'ntoskrnl.iomakeassociatedirp':( 'int', None, 'stdcall', 'ntoskrnl.IoMakeAssociatedIrp', (('int', None), ('int', None)) ),
    'ntoskrnl.ioopendeviceinterfaceregistrykey':( 'int', None, 'stdcall', 'ntoskrnl.IoOpenDeviceInterfaceRegistryKey', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ioopendeviceregistrykey':( 'int', None, 'thiscall', 'ntoskrnl.IoOpenDeviceRegistryKey', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iopageread':( 'int', None, 'stdcall', 'ntoskrnl.IoPageRead', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iopnpdeliverservicepowernotification':( 'int', None, 'stdcall', 'ntoskrnl.IoPnPDeliverServicePowerNotification', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioquerydevicedescription':( 'int', None, 'thiscall', 'ntoskrnl.IoQueryDeviceDescription', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioqueryfiledosdevicename':( 'int', None, 'stdcall', 'ntoskrnl.IoQueryFileDosDeviceName', (('void *', 'obj'), ('void *', 'ptr')) ),
    'ntoskrnl.ioqueryfileinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoQueryFileInformation', (('void *', 'obj'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ioqueryvolumeinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoQueryVolumeInformation', (('void *', 'obj'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ioqueuethreadirp':( 'int', None, 'stdcall', 'ntoskrnl.IoQueueThreadIrp', (('int', None),) ),
    'ntoskrnl.ioqueueworkitem':( 'int', None, 'stdcall', 'ntoskrnl.IoQueueWorkItem', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioraiseharderror':( 'int', None, 'stdcall', 'ntoskrnl.IoRaiseHardError', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ioraiseinformationalharderror':( 'int', None, 'stdcall', 'ntoskrnl.IoRaiseInformationalHardError', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreaddisksignature':( 'int', None, 'stdcall', 'ntoskrnl.IoReadDiskSignature', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ioreadoperationcount':( 'int', None, 'cdecl', 'ntoskrnl.IoReadOperationCount', () ),
    'ntoskrnl.ioreadpartitiontable':( 'int', None, 'msfastcall', 'ntoskrnl.IoReadPartitionTable', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ioreadpartitiontableex':( 'int', None, 'stdcall', 'ntoskrnl.IoReadPartitionTableEx', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ioreadtransfercount':( 'int', None, 'cdecl', 'ntoskrnl.IoReadTransferCount', () ),
    'ntoskrnl.ioregisterbootdriverreinitialization':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterBootDriverReinitialization', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioregisterdeviceinterface':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterDeviceInterface', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ioregisterdriverreinitialization':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterDriverReinitialization', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioregisterfilesystem':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterFileSystem', (('int', None),) ),
    'ntoskrnl.ioregisterfsregistrationchange':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterFsRegistrationChange', (('void *', 'obj'), ('void *', 'funcptr')) ),
    'ntoskrnl.ioregisterlastchanceshutdownnotification':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterLastChanceShutdownNotification', (('void *', 'obj'),) ),
    'ntoskrnl.ioregisterplugplaynotification':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterPlugPlayNotification', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'obj'), ('void *', 'funcptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioregistershutdownnotification':( 'int', None, 'stdcall', 'ntoskrnl.IoRegisterShutdownNotification', (('void *', 'obj'),) ),
    'ntoskrnl.ioreleasecancelspinlock':( 'int', None, 'stdcall', 'ntoskrnl.IoReleaseCancelSpinLock', (('int', None),) ),
    'ntoskrnl.ioreleaseremovelockandwaitex':( 'int', None, 'stdcall', 'ntoskrnl.IoReleaseRemoveLockAndWaitEx', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreleaseremovelockex':( 'int', None, 'stdcall', 'ntoskrnl.IoReleaseRemoveLockEx', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreleasevpbspinlock':( 'int', None, 'stdcall', 'ntoskrnl.IoReleaseVpbSpinLock', (('int', None),) ),
    'ntoskrnl.ioremoveshareaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoRemoveShareAccess', (('int', None), ('int', None)) ),
    'ntoskrnl.ioreportdetecteddevice':( 'int', None, 'thiscall', 'ntoskrnl.IoReportDetectedDevice', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreporthalresourceusage':( 'int', None, 'stdcall', 'ntoskrnl.IoReportHalResourceUsage', (('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ioreportresourcefordetection':( 'int', None, 'thiscall', 'ntoskrnl.IoReportResourceForDetection', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreportresourceusage':( 'int', None, 'thiscall', 'ntoskrnl.IoReportResourceUsage', (('void *', 'obj'), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ioreporttargetdevicechange':( 'int', None, 'stdcall', 'ntoskrnl.IoReportTargetDeviceChange', (('void *', 'obj'), ('void *', 'ptr')) ),
    'ntoskrnl.ioreporttargetdevicechangeasynchronous':( 'int', None, 'stdcall', 'ntoskrnl.IoReportTargetDeviceChangeAsynchronous', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.iorequestdeviceeject':( 'int', None, 'stdcall', 'ntoskrnl.IoRequestDeviceEject', (('void *', 'obj'),) ),
    'ntoskrnl.ioreuseirp':( 'int', None, 'stdcall', 'ntoskrnl.IoReuseIrp', (('int', None), ('int', None)) ),
    'ntoskrnl.iosetcompletionroutineex':( 'int', None, 'stdcall', 'ntoskrnl.IoSetCompletionRoutineEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetdeviceinterfacestate':( 'int', None, 'stdcall', 'ntoskrnl.IoSetDeviceInterfaceState', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.iosetdevicetoverify':( 'int', None, 'stdcall', 'ntoskrnl.IoSetDeviceToVerify', (('int', None), ('int', None)) ),
    'ntoskrnl.iosetfileorigin':( 'int', None, 'stdcall', 'ntoskrnl.IoSetFileOrigin', (('int', None), ('int', None)) ),
    'ntoskrnl.iosetharderrororverifydevice':( 'int', None, 'stdcall', 'ntoskrnl.IoSetHardErrorOrVerifyDevice', (('int', None), ('int', None)) ),
    'ntoskrnl.iosetinformation':( 'int', None, 'stdcall', 'ntoskrnl.IoSetInformation', (('void *', 'obj'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.iosetiocompletion':( 'int', None, 'stdcall', 'ntoskrnl.IoSetIoCompletion', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetpartitioninformation':( 'int', None, 'msfastcall', 'ntoskrnl.IoSetPartitionInformation', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetpartitioninformationex':( 'int', None, 'stdcall', 'ntoskrnl.IoSetPartitionInformationEx', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetshareaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoSetShareAccess', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetstartioattributes':( 'int', None, 'stdcall', 'ntoskrnl.IoSetStartIoAttributes', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iosetsystempartition':( 'int', None, 'stdcall', 'ntoskrnl.IoSetSystemPartition', (('int', None),) ),
    'ntoskrnl.iosetthreadharderrormode':( 'int', None, 'stdcall', 'ntoskrnl.IoSetThreadHardErrorMode', (('int', None),) ),
    'ntoskrnl.iosettoplevelirp':( 'int', None, 'stdcall', 'ntoskrnl.IoSetTopLevelIrp', (('int', None),) ),
    'ntoskrnl.iostartnextpacket':( 'int', None, 'stdcall', 'ntoskrnl.IoStartNextPacket', (('int', None), ('int', None)) ),
    'ntoskrnl.iostartnextpacketbykey':( 'int', None, 'stdcall', 'ntoskrnl.IoStartNextPacketByKey', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iostartpacket':( 'int', None, 'stdcall', 'ntoskrnl.IoStartPacket', (('int', None), ('int', None), ('int', None), ('void *', 'funcptr')) ),
    'ntoskrnl.iostarttimer':( 'int', None, 'stdcall', 'ntoskrnl.IoStartTimer', (('int', None),) ),
    'ntoskrnl.iostatisticslock':( 'int', None, 'cdecl', 'ntoskrnl.IoStatisticsLock', () ),
    'ntoskrnl.iostoptimer':( 'int', None, 'stdcall', 'ntoskrnl.IoStopTimer', (('int', None),) ),
    'ntoskrnl.iosynchronousinvalidatedevicerelations':( 'int', None, 'stdcall', 'ntoskrnl.IoSynchronousInvalidateDeviceRelations', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iosynchronouspagewrite':( 'int', None, 'stdcall', 'ntoskrnl.IoSynchronousPageWrite', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.iothreadtoprocess':( 'int', None, 'stdcall', 'ntoskrnl.IoThreadToProcess', (('int', None),) ),
    'ntoskrnl.iounregisterfilesystem':( 'int', None, 'stdcall', 'ntoskrnl.IoUnregisterFileSystem', (('int', None),) ),
    'ntoskrnl.iounregisterfsregistrationchange':( 'int', None, 'stdcall', 'ntoskrnl.IoUnregisterFsRegistrationChange', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iounregisterplugplaynotification':( 'int', None, 'stdcall', 'ntoskrnl.IoUnregisterPlugPlayNotification', (('void *', 'ptr'),) ),
    'ntoskrnl.iounregistershutdownnotification':( 'int', None, 'stdcall', 'ntoskrnl.IoUnregisterShutdownNotification', (('void *', 'obj'),) ),
    'ntoskrnl.ioupdateshareaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoUpdateShareAccess', (('int', None), ('int', None)) ),
    'ntoskrnl.iovalidatedeviceiocontrolaccess':( 'int', None, 'stdcall', 'ntoskrnl.IoValidateDeviceIoControlAccess', (('int', None), ('int', None)) ),
    'ntoskrnl.ioverifypartitiontable':( 'int', None, 'stdcall', 'ntoskrnl.IoVerifyPartitionTable', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ioverifyvolume':( 'int', None, 'stdcall', 'ntoskrnl.IoVerifyVolume', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iovolumedevicetodosname':( 'int', None, 'stdcall', 'ntoskrnl.IoVolumeDeviceToDosName', (('int', None), ('int', None)) ),
    'ntoskrnl.iowmiallocateinstanceids':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIAllocateInstanceIds', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmideviceobjecttoinstancename':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIDeviceObjectToInstanceName', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiexecutemethod':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIExecuteMethod', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmihandletoinstancename':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIHandleToInstanceName', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiopenblock':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIOpenBlock', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iowmiqueryalldata':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIQueryAllData', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiqueryalldatamultiple':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIQueryAllDataMultiple', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiquerysingleinstance':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIQuerySingleInstance', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiquerysingleinstancemultiple':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIQuerySingleInstanceMultiple', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiregistrationcontrol':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIRegistrationControl', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.iowmisetnotificationcallback':( 'int', None, 'stdcall', 'ntoskrnl.IoWMISetNotificationCallback', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmisetsingleinstance':( 'int', None, 'stdcall', 'ntoskrnl.IoWMISetSingleInstance', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmisetsingleitem':( 'int', None, 'stdcall', 'ntoskrnl.IoWMISetSingleItem', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmisuggestinstancename':( 'int', None, 'stdcall', 'ntoskrnl.IoWMISuggestInstanceName', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.iowmiwriteevent':( 'int', None, 'stdcall', 'ntoskrnl.IoWMIWriteEvent', (('void *', 'obj'),) ),
    'ntoskrnl.iowriteerrorlogentry':( 'int', None, 'stdcall', 'ntoskrnl.IoWriteErrorLogEntry', (('int', None),) ),
    'ntoskrnl.iowriteoperationcount':( 'int', None, 'cdecl', 'ntoskrnl.IoWriteOperationCount', () ),
    'ntoskrnl.iowritepartitiontable':( 'int', None, 'msfastcall', 'ntoskrnl.IoWritePartitionTable', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.iowritepartitiontableex':( 'int', None, 'stdcall', 'ntoskrnl.IoWritePartitionTableEx', (('int', None), ('int', None)) ),
    'ntoskrnl.iowritetransfercount':( 'int', None, 'cdecl', 'ntoskrnl.IoWriteTransferCount', () ),
    'ntoskrnl.iofcalldriver':( 'int', None, 'cdecl', 'ntoskrnl.IofCallDriver', () ),
    'ntoskrnl.iofcompleterequest':( 'int', None, 'cdecl', 'ntoskrnl.IofCompleteRequest', () ),
    'ntoskrnl.kddebuggerenabled':( 'int', None, 'cdecl', 'ntoskrnl.KdDebuggerEnabled', () ),
    'ntoskrnl.kddebuggernotpresent':( 'int', None, 'cdecl', 'ntoskrnl.KdDebuggerNotPresent', () ),
    'ntoskrnl.kddisabledebugger':( 'int', None, 'cdecl', 'ntoskrnl.KdDisableDebugger', () ),
    'ntoskrnl.kdenabledebugger':( 'int', None, 'cdecl', 'ntoskrnl.KdEnableDebugger', () ),
    'ntoskrnl.kdentereddebugger':( 'int', None, 'cdecl', 'ntoskrnl.KdEnteredDebugger', () ),
    'ntoskrnl.kdpollbreakin':( 'int', None, 'cdecl', 'ntoskrnl.KdPollBreakIn', () ),
    'ntoskrnl.kdpowertransition':( 'int', None, 'stdcall', 'ntoskrnl.KdPowerTransition', (('int', None),) ),
    'ntoskrnl.ke386callbios':( 'int', None, 'stdcall', 'ntoskrnl.Ke386CallBios', (('int', None), ('int', None)) ),
    'ntoskrnl.ke386iosetaccessprocess':( 'int', None, 'stdcall', 'ntoskrnl.Ke386IoSetAccessProcess', (('int', None), ('int', None)) ),
    'ntoskrnl.ke386queryioaccessmap':( 'int', None, 'stdcall', 'ntoskrnl.Ke386QueryIoAccessMap', (('int', None), ('int', None)) ),
    'ntoskrnl.ke386setioaccessmap':( 'int', None, 'stdcall', 'ntoskrnl.Ke386SetIoAccessMap', (('int', None), ('int', None)) ),
    'ntoskrnl.keacquireinstackqueuedspinlockatdpclevel':( 'int', None, 'cdecl', 'ntoskrnl.KeAcquireInStackQueuedSpinLockAtDpcLevel', () ),
    'ntoskrnl.keacquireinterruptspinlock':( 'int', None, 'stdcall', 'ntoskrnl.KeAcquireInterruptSpinLock', (('int', None),) ),
    'ntoskrnl.keacquirespinlockatdpclevel':( 'int', None, 'stdcall', 'ntoskrnl.KeAcquireSpinLockAtDpcLevel', (('int', None),) ),
    'ntoskrnl.keaddsystemservicetable':( 'int', None, 'stdcall', 'ntoskrnl.KeAddSystemServiceTable', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keareapcsdisabled':( 'int', None, 'cdecl', 'ntoskrnl.KeAreApcsDisabled', () ),
    'ntoskrnl.keattachprocess':( 'int', None, 'stdcall', 'ntoskrnl.KeAttachProcess', (('int', None),) ),
    'ntoskrnl.kebugcheck':( 'int', None, 'stdcall', 'ntoskrnl.KeBugCheck', (('int', None),) ),
    'ntoskrnl.kebugcheckex':( 'int', None, 'stdcall', 'ntoskrnl.KeBugCheckEx', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.kecanceltimer':( 'int', None, 'stdcall', 'ntoskrnl.KeCancelTimer', (('void *', 'ptr'),) ),
    'ntoskrnl.kecapturepersistentthreadstate':( 'int', None, 'stdcall', 'ntoskrnl.KeCapturePersistentThreadState', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keclearevent':( 'int', None, 'stdcall', 'ntoskrnl.KeClearEvent', (('int', None),) ),
    'ntoskrnl.keconnectinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.KeConnectInterrupt', (('int', None),) ),
    'ntoskrnl.kedcacheflushcount':( 'int', None, 'cdecl', 'ntoskrnl.KeDcacheFlushCount', () ),
    'ntoskrnl.kedelayexecutionthread':( 'int', None, 'stdcall', 'ntoskrnl.KeDelayExecutionThread', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.kederegisterbugcheckcallback':( 'int', None, 'stdcall', 'ntoskrnl.KeDeregisterBugCheckCallback', (('int', None),) ),
    'ntoskrnl.kederegisterbugcheckreasoncallback':( 'int', None, 'stdcall', 'ntoskrnl.KeDeregisterBugCheckReasonCallback', (('int', None),) ),
    'ntoskrnl.kedetachprocess':( 'int', None, 'cdecl', 'ntoskrnl.KeDetachProcess', () ),
    'ntoskrnl.kedisconnectinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.KeDisconnectInterrupt', (('int', None),) ),
    'ntoskrnl.keentercriticalregion':( 'int', None, 'cdecl', 'ntoskrnl.KeEnterCriticalRegion', () ),
    'ntoskrnl.keenterkerneldebugger':( 'int', None, 'cdecl', 'ntoskrnl.KeEnterKernelDebugger', () ),
    'ntoskrnl.kefindconfigurationentry':( 'int', None, 'stdcall', 'ntoskrnl.KeFindConfigurationEntry', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kefindconfigurationnextentry':( 'int', None, 'stdcall', 'ntoskrnl.KeFindConfigurationNextEntry', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.keflushentiretb':( 'int', None, 'stdcall', 'ntoskrnl.KeFlushEntireTb', (('int', None), ('int', None)) ),
    'ntoskrnl.keflushqueueddpcs':( 'int', None, 'cdecl', 'ntoskrnl.KeFlushQueuedDpcs', () ),
    'ntoskrnl.kegetcurrentthread':( 'int', None, 'cdecl', 'ntoskrnl.KeGetCurrentThread', () ),
    'ntoskrnl.kegetpreviousmode':( 'int', None, 'cdecl', 'ntoskrnl.KeGetPreviousMode', () ),
    'ntoskrnl.kegetrecommendedshareddataalignment':( 'int', None, 'cdecl', 'ntoskrnl.KeGetRecommendedSharedDataAlignment', () ),
    'ntoskrnl.kei386abioscall':( 'int', None, 'stdcall', 'ntoskrnl.KeI386AbiosCall', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kei386allocategdtselectors':( 'int', None, 'stdcall', 'ntoskrnl.KeI386AllocateGdtSelectors', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.kei386call16bitcstylefunction':( 'int', None, 'cdecl', 'ntoskrnl.KeI386Call16BitCStyleFunction', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kei386call16bitfunction':( 'int', None, 'cdecl', 'ntoskrnl.KeI386Call16BitFunction', (('int', None),) ),
    'ntoskrnl.kei386flattogdtselector':( 'int', None, 'stdcall', 'ntoskrnl.KeI386FlatToGdtSelector', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kei386getlid':( 'int', None, 'stdcall', 'ntoskrnl.KeI386GetLid', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kei386machinetype':( 'int', None, 'cdecl', 'ntoskrnl.KeI386MachineType', () ),
    'ntoskrnl.kei386releasegdtselectors':( 'int', None, 'stdcall', 'ntoskrnl.KeI386ReleaseGdtSelectors', (('int', None), ('int', None)) ),
    'ntoskrnl.kei386releaselid':( 'int', None, 'stdcall', 'ntoskrnl.KeI386ReleaseLid', (('int', None), ('int', None)) ),
    'ntoskrnl.kei386setgdtselector':( 'int', None, 'stdcall', 'ntoskrnl.KeI386SetGdtSelector', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.keicacheflushcount':( 'int', None, 'cdecl', 'ntoskrnl.KeIcacheFlushCount', () ),
    'ntoskrnl.keinitializeapc':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeApc', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keinitializedevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeDeviceQueue', (('int', None),) ),
    'ntoskrnl.keinitializedpc':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeDpc', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.keinitializeevent':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeEvent', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keinitializeinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeInterrupt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keinitializemutant':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeMutant', (('int', None), ('int', None)) ),
    'ntoskrnl.keinitializemutex':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeMutex', (('int', None), ('int', None)) ),
    'ntoskrnl.keinitializequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeQueue', (('int', None), ('int', None)) ),
    'ntoskrnl.keinitializesemaphore':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeSemaphore', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keinitializespinlock':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeSpinLock', (('int', None),) ),
    'ntoskrnl.keinitializetimer':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeTimer', (('void *', 'ptr'),) ),
    'ntoskrnl.keinitializetimerex':( 'int', None, 'stdcall', 'ntoskrnl.KeInitializeTimerEx', (('int', None), ('int', None)) ),
    'ntoskrnl.keinsertbykeydevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertByKeyDeviceQueue', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keinsertdevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertDeviceQueue', (('int', None), ('int', None)) ),
    'ntoskrnl.keinsertheadqueue':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertHeadQueue', (('int', None), ('int', None)) ),
    'ntoskrnl.keinsertqueue':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertQueue', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.keinsertqueueapc':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertQueueApc', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.keinsertqueuedpc':( 'int', None, 'stdcall', 'ntoskrnl.KeInsertQueueDpc', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.keisattachedprocess':( 'int', None, 'cdecl', 'ntoskrnl.KeIsAttachedProcess', () ),
    'ntoskrnl.keisexecutingdpc':( 'int', None, 'cdecl', 'ntoskrnl.KeIsExecutingDpc', () ),
    'ntoskrnl.keleavecriticalregion':( 'int', None, 'cdecl', 'ntoskrnl.KeLeaveCriticalRegion', () ),
    'ntoskrnl.keloaderblock':( 'int', None, 'cdecl', 'ntoskrnl.KeLoaderBlock', () ),
    'ntoskrnl.kenumberprocessors':( 'int', None, 'cdecl', 'ntoskrnl.KeNumberProcessors', () ),
    'ntoskrnl.keprofileinterrupt':( 'int', None, 'stdcall', 'ntoskrnl.KeProfileInterrupt', (('int', None), ('int', None)) ),
    'ntoskrnl.keprofileinterruptwithsource':( 'int', None, 'stdcall', 'ntoskrnl.KeProfileInterruptWithSource', (('int', None), ('int', None)) ),
    'ntoskrnl.kepulseevent':( 'int', None, 'stdcall', 'ntoskrnl.KePulseEvent', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kequeryactiveprocessors':( 'int', None, 'cdecl', 'ntoskrnl.KeQueryActiveProcessors', () ),
    'ntoskrnl.kequeryinterrupttime':( 'int', None, 'cdecl', 'ntoskrnl.KeQueryInterruptTime', () ),
    'ntoskrnl.kequeryprioritythread':( 'int', None, 'stdcall', 'ntoskrnl.KeQueryPriorityThread', (('int', None),) ),
    'ntoskrnl.kequeryruntimethread':( 'int', None, 'stdcall', 'ntoskrnl.KeQueryRuntimeThread', (('int', None), ('int', None)) ),
    'ntoskrnl.kequerysystemtime':( 'int', None, 'stdcall', 'ntoskrnl.KeQuerySystemTime', (('void *', 'ptr'),) ),
    'ntoskrnl.kequerytickcount':( 'int', None, 'stdcall', 'ntoskrnl.KeQueryTickCount', (('void *', 'ptr'),) ),
    'ntoskrnl.kequerytimeincrement':( 'int', None, 'cdecl', 'ntoskrnl.KeQueryTimeIncrement', () ),
    'ntoskrnl.keraiseuserexception':( 'int', None, 'stdcall', 'ntoskrnl.KeRaiseUserException', (('int', None),) ),
    'ntoskrnl.kereadstateevent':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateEvent', (('int', None),) ),
    'ntoskrnl.kereadstatemutant':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateMutant', (('int', None),) ),
    'ntoskrnl.kereadstatemutex':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateMutex', (('int', None),) ),
    'ntoskrnl.kereadstatequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateQueue', (('int', None),) ),
    'ntoskrnl.kereadstatesemaphore':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateSemaphore', (('int', None),) ),
    'ntoskrnl.kereadstatetimer':( 'int', None, 'stdcall', 'ntoskrnl.KeReadStateTimer', (('int', None),) ),
    'ntoskrnl.keregisterbugcheckcallback':( 'int', None, 'stdcall', 'ntoskrnl.KeRegisterBugCheckCallback', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keregisterbugcheckreasoncallback':( 'int', None, 'stdcall', 'ntoskrnl.KeRegisterBugCheckReasonCallback', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kereleaseinstackqueuedspinlockfromdpclevel':( 'int', None, 'cdecl', 'ntoskrnl.KeReleaseInStackQueuedSpinLockFromDpcLevel', () ),
    'ntoskrnl.kereleaseinterruptspinlock':( 'int', None, 'stdcall', 'ntoskrnl.KeReleaseInterruptSpinLock', (('int', None), ('int', None)) ),
    'ntoskrnl.kereleasemutant':( 'int', None, 'stdcall', 'ntoskrnl.KeReleaseMutant', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kereleasemutex':( 'int', None, 'stdcall', 'ntoskrnl.KeReleaseMutex', (('int', None), ('int', None)) ),
    'ntoskrnl.kereleasesemaphore':( 'int', None, 'stdcall', 'ntoskrnl.KeReleaseSemaphore', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kereleasespinlockfromdpclevel':( 'int', None, 'stdcall', 'ntoskrnl.KeReleaseSpinLockFromDpcLevel', (('int', None),) ),
    'ntoskrnl.keremovebykeydevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveByKeyDeviceQueue', (('int', None), ('int', None)) ),
    'ntoskrnl.keremovebykeydevicequeueifbusy':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveByKeyDeviceQueueIfBusy', (('int', None), ('int', None)) ),
    'ntoskrnl.keremovedevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveDeviceQueue', (('int', None),) ),
    'ntoskrnl.keremoveentrydevicequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveEntryDeviceQueue', (('int', None), ('int', None)) ),
    'ntoskrnl.keremovequeue':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveQueue', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keremovequeuedpc':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveQueueDpc', (('int', None),) ),
    'ntoskrnl.keremovesystemservicetable':( 'int', None, 'stdcall', 'ntoskrnl.KeRemoveSystemServiceTable', (('int', None),) ),
    'ntoskrnl.keresetevent':( 'int', None, 'stdcall', 'ntoskrnl.KeResetEvent', (('void *', 'ptr'),) ),
    'ntoskrnl.kerestorefloatingpointstate':( 'int', None, 'stdcall', 'ntoskrnl.KeRestoreFloatingPointState', (('int', None),) ),
    'ntoskrnl.kereverttouseraffinitythread':( 'int', None, 'cdecl', 'ntoskrnl.KeRevertToUserAffinityThread', () ),
    'ntoskrnl.kerundownqueue':( 'int', None, 'stdcall', 'ntoskrnl.KeRundownQueue', (('int', None),) ),
    'ntoskrnl.kesavefloatingpointstate':( 'int', None, 'stdcall', 'ntoskrnl.KeSaveFloatingPointState', (('int', None),) ),
    'ntoskrnl.kesavestateforhibernate':( 'int', None, 'cdecl', 'ntoskrnl.KeSaveStateForHibernate', (('void *', 'ptr'),) ),
    'ntoskrnl.keservicedescriptortable':( 'int', None, 'cdecl', 'ntoskrnl.KeServiceDescriptorTable', () ),
    'ntoskrnl.kesetaffinitythread':( 'int', None, 'stdcall', 'ntoskrnl.KeSetAffinityThread', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.kesetbaseprioritythread':( 'int', None, 'stdcall', 'ntoskrnl.KeSetBasePriorityThread', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.kesetdmaiocoherency':( 'int', None, 'stdcall', 'ntoskrnl.KeSetDmaIoCoherency', (('int', None),) ),
    'ntoskrnl.kesetevent':( 'int', None, 'stdcall', 'ntoskrnl.KeSetEvent', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.keseteventboostpriority':( 'int', None, 'stdcall', 'ntoskrnl.KeSetEventBoostPriority', (('int', None), ('int', None)) ),
    'ntoskrnl.kesetidealprocessorthread':( 'int', None, 'stdcall', 'ntoskrnl.KeSetIdealProcessorThread', (('int', None), ('int', None)) ),
    'ntoskrnl.kesetimportancedpc':( 'int', None, 'stdcall', 'ntoskrnl.KeSetImportanceDpc', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.kesetkernelstackswapenable':( 'int', None, 'stdcall', 'ntoskrnl.KeSetKernelStackSwapEnable', (('int', None),) ),
    'ntoskrnl.kesetprioritythread':( 'int', None, 'stdcall', 'ntoskrnl.KeSetPriorityThread', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.kesetprofileirql':( 'int', None, 'stdcall', 'ntoskrnl.KeSetProfileIrql', (('int', None),) ),
    'ntoskrnl.kesetsystemaffinitythread':( 'int', None, 'stdcall', 'ntoskrnl.KeSetSystemAffinityThread', (('int', None),) ),
    'ntoskrnl.kesettargetprocessordpc':( 'int', None, 'stdcall', 'ntoskrnl.KeSetTargetProcessorDpc', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.kesettimeincrement':( 'int', None, 'stdcall', 'ntoskrnl.KeSetTimeIncrement', (('int', None), ('int', None)) ),
    'ntoskrnl.kesettimeupdatenotifyroutine':( 'int', None, 'cdecl', 'ntoskrnl.KeSetTimeUpdateNotifyRoutine', () ),
    'ntoskrnl.kesettimer':( 'int', None, 'stdcall', 'ntoskrnl.KeSetTimer', (('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kesettimerex':( 'int', None, 'stdcall', 'ntoskrnl.KeSetTimerEx', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kestackattachprocess':( 'int', None, 'stdcall', 'ntoskrnl.KeStackAttachProcess', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.kesynchronizeexecution':( 'int', None, 'stdcall', 'ntoskrnl.KeSynchronizeExecution', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keterminatethread':( 'int', None, 'stdcall', 'ntoskrnl.KeTerminateThread', (('int', None),) ),
    'ntoskrnl.ketickcount':( 'int', None, 'cdecl', 'ntoskrnl.KeTickCount', () ),
    'ntoskrnl.keunstackdetachprocess':( 'int', None, 'stdcall', 'ntoskrnl.KeUnstackDetachProcess', (('void *', 'ptr'),) ),
    'ntoskrnl.keupdateruntime':( 'int', None, 'stdcall', 'ntoskrnl.KeUpdateRunTime', (('int', None),) ),
    'ntoskrnl.keupdatesystemtime':( 'int', None, 'cdecl', 'ntoskrnl.KeUpdateSystemTime', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.keusermodecallback':( 'int', None, 'stdcall', 'ntoskrnl.KeUserModeCallback', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kewaitformultipleobjects':( 'int', None, 'stdcall', 'ntoskrnl.KeWaitForMultipleObjects', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.kewaitformutexobject':( 'int', None, 'stdcall', 'ntoskrnl.KeWaitForMutexObject', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.kewaitforsingleobject':( 'int', None, 'stdcall', 'ntoskrnl.KeWaitForSingleObject', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.kefacquirespinlockatdpclevel':( 'int', None, 'cdecl', 'ntoskrnl.KefAcquireSpinLockAtDpcLevel', () ),
    'ntoskrnl.kefreleasespinlockfromdpclevel':( 'int', None, 'cdecl', 'ntoskrnl.KefReleaseSpinLockFromDpcLevel', () ),
    'ntoskrnl.kei386eoihelper':( 'int', None, 'cdecl', 'ntoskrnl.Kei386EoiHelper', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.kiacquirespinlock':( 'int', None, 'cdecl', 'ntoskrnl.KiAcquireSpinLock', () ),
    'ntoskrnl.kibugcheckdata':( 'int', None, 'cdecl', 'ntoskrnl.KiBugCheckData', () ),
    'ntoskrnl.kicoprocessorerror':( 'int', None, 'cdecl', 'ntoskrnl.KiCoprocessorError', () ),
    'ntoskrnl.kideliverapc':( 'int', None, 'stdcall', 'ntoskrnl.KiDeliverApc', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.kidispatchinterrupt':( 'int', None, 'cdecl', 'ntoskrnl.KiDispatchInterrupt', () ),
    'ntoskrnl.kienabletimerwatchdog':( 'int', None, 'cdecl', 'ntoskrnl.KiEnableTimerWatchdog', () ),
    'ntoskrnl.kiipiserviceroutine':( 'int', None, 'stdcall', 'ntoskrnl.KiIpiServiceRoutine', (('int', None), ('int', None)) ),
    'ntoskrnl.kireleasespinlock':( 'int', None, 'cdecl', 'ntoskrnl.KiReleaseSpinLock', () ),
    'ntoskrnl.kiunexpectedinterrupt':( 'int', None, 'cdecl', 'ntoskrnl.KiUnexpectedInterrupt', () ),
    'ntoskrnl.kii386spinonspinlock':( 'int', None, 'stdcall', 'ntoskrnl.Kii386SpinOnSpinLock', (('int', None), ('int', None)) ),
    'ntoskrnl.ldraccessresource':( 'int', None, 'stdcall', 'ntoskrnl.LdrAccessResource', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.ldrenumresources':( 'int', None, 'stdcall', 'ntoskrnl.LdrEnumResources', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ldrfindresourcedirectory_u':( 'int', None, 'stdcall', 'ntoskrnl.LdrFindResourceDirectory_U', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ldrfindresource_u':( 'int', None, 'stdcall', 'ntoskrnl.LdrFindResource_U', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.lpcportobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.LpcPortObjectType', () ),
    'ntoskrnl.lpcrequestport':( 'int', None, 'stdcall', 'ntoskrnl.LpcRequestPort', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.lpcrequestwaitreplyport':( 'int', None, 'stdcall', 'ntoskrnl.LpcRequestWaitReplyPort', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.lsacallauthenticationpackage':( 'int', None, 'stdcall', 'ntoskrnl.LsaCallAuthenticationPackage', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.lsaderegisterlogonprocess':( 'int', None, 'stdcall', 'ntoskrnl.LsaDeregisterLogonProcess', (('int', None),) ),
    'ntoskrnl.lsafreereturnbuffer':( 'int', None, 'stdcall', 'ntoskrnl.LsaFreeReturnBuffer', (('int', None),) ),
    'ntoskrnl.lsalogonuser':( 'int', None, 'stdcall', 'ntoskrnl.LsaLogonUser', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.lsalookupauthenticationpackage':( 'int', None, 'stdcall', 'ntoskrnl.LsaLookupAuthenticationPackage', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.lsaregisterlogonprocess':( 'int', None, 'stdcall', 'ntoskrnl.LsaRegisterLogonProcess', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mm64bitphysicaladdress':( 'int', None, 'cdecl', 'ntoskrnl.Mm64BitPhysicalAddress', () ),
    'ntoskrnl.mmaddphysicalmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmAddPhysicalMemory', (('int', None), ('int', None)) ),
    'ntoskrnl.mmaddverifierthunks':( 'int', None, 'stdcall', 'ntoskrnl.MmAddVerifierThunks', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.mmadjustworkingsetsize':( 'int', None, 'stdcall', 'ntoskrnl.MmAdjustWorkingSetSize', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmadvancemdl':( 'int', None, 'stdcall', 'ntoskrnl.MmAdvanceMdl', (('int', None), ('int', None)) ),
    'ntoskrnl.mmallocatecontiguousmemory':( 'int', None, 'thiscall', 'ntoskrnl.MmAllocateContiguousMemory', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmallocatecontiguousmemoryspecifycache':( 'int', None, 'thiscall', 'ntoskrnl.MmAllocateContiguousMemorySpecifyCache', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmallocatemappingaddress':( 'int', None, 'thiscall', 'ntoskrnl.MmAllocateMappingAddress', (('void *', 'obj'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.mmallocatenoncachedmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmAllocateNonCachedMemory', (('int', None),) ),
    'ntoskrnl.mmallocatepagesformdl':( 'int', None, 'stdcall', 'ntoskrnl.MmAllocatePagesForMdl', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmbuildmdlfornonpagedpool':( 'int', None, 'stdcall', 'ntoskrnl.MmBuildMdlForNonPagedPool', (('int', None),) ),
    'ntoskrnl.mmcanfilebetruncated':( 'int', None, 'stdcall', 'ntoskrnl.MmCanFileBeTruncated', (('int', None), ('int', None)) ),
    'ntoskrnl.mmcommitsessionmappedview':( 'int', None, 'stdcall', 'ntoskrnl.MmCommitSessionMappedView', (('int', None), ('int', None)) ),
    'ntoskrnl.mmcreatemdl':( 'int', None, 'stdcall', 'ntoskrnl.MmCreateMdl', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmcreatesection':( 'int', None, 'stdcall', 'ntoskrnl.MmCreateSection', (('void *', 'ptr'), ('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'obj')) ),
    'ntoskrnl.mmdisablemodifiedwriteofsection':( 'int', None, 'stdcall', 'ntoskrnl.MmDisableModifiedWriteOfSection', (('int', None),) ),
    'ntoskrnl.mmflushimagesection':( 'int', None, 'thiscall', 'ntoskrnl.MmFlushImageSection', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmforcesectionclosed':( 'int', None, 'thiscall', 'ntoskrnl.MmForceSectionClosed', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmfreecontiguousmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmFreeContiguousMemory', (('void *', 'ptr'),) ),
    'ntoskrnl.mmfreecontiguousmemoryspecifycache':( 'int', None, 'stdcall', 'ntoskrnl.MmFreeContiguousMemorySpecifyCache', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmfreemappingaddress':( 'int', None, 'stdcall', 'ntoskrnl.MmFreeMappingAddress', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.mmfreenoncachedmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmFreeNonCachedMemory', (('int', None), ('int', None)) ),
    'ntoskrnl.mmfreepagesfrommdl':( 'int', None, 'stdcall', 'ntoskrnl.MmFreePagesFromMdl', (('void *', 'ptr'),) ),
    'ntoskrnl.mmgetphysicaladdress':( 'int', None, 'stdcall', 'ntoskrnl.MmGetPhysicalAddress', (('int', None),) ),
    'ntoskrnl.mmgetphysicalmemoryranges':( 'int', None, 'cdecl', 'ntoskrnl.MmGetPhysicalMemoryRanges', () ),
    'ntoskrnl.mmgetsystemroutineaddress':( 'int', None, 'stdcall', 'ntoskrnl.MmGetSystemRoutineAddress', (('void *', 'ptr'),) ),
    'ntoskrnl.mmgetvirtualforphysical':( 'int', None, 'stdcall', 'ntoskrnl.MmGetVirtualForPhysical', (('int', None), ('int', None)) ),
    'ntoskrnl.mmgrowkernelstack':( 'int', None, 'stdcall', 'ntoskrnl.MmGrowKernelStack', (('void *', 'ptr'),) ),
    'ntoskrnl.mmhighestuseraddress':( 'int', None, 'cdecl', 'ntoskrnl.MmHighestUserAddress', () ),
    'ntoskrnl.mmisaddressvalid':( 'int', None, 'stdcall', 'ntoskrnl.MmIsAddressValid', (('int', None),) ),
    'ntoskrnl.mmisdriververifying':( 'int', None, 'stdcall', 'ntoskrnl.MmIsDriverVerifying', (('int', None),) ),
    'ntoskrnl.mmisnonpagedsystemaddressvalid':( 'int', None, 'stdcall', 'ntoskrnl.MmIsNonPagedSystemAddressValid', (('int', None),) ),
    'ntoskrnl.mmisrecursiveiofault':( 'int', None, 'cdecl', 'ntoskrnl.MmIsRecursiveIoFault', () ),
    'ntoskrnl.mmisthisanntassystem':( 'int', None, 'cdecl', 'ntoskrnl.MmIsThisAnNtAsSystem', () ),
    'ntoskrnl.mmisverifierenabled':( 'int', None, 'stdcall', 'ntoskrnl.MmIsVerifierEnabled', (('void *', 'ptr'),) ),
    'ntoskrnl.mmlockpagabledatasection':( 'int', None, 'stdcall', 'ntoskrnl.MmLockPagableDataSection', (('int', None),) ),
    'ntoskrnl.mmlockpagableimagesection':( 'int', None, 'stdcall', 'ntoskrnl.MmLockPagableImageSection', (('int', None),) ),
    'ntoskrnl.mmlockpagablesectionbyhandle':( 'int', None, 'stdcall', 'ntoskrnl.MmLockPagableSectionByHandle', (('int', None),) ),
    'ntoskrnl.mmmapiospace':( 'int', None, 'stdcall', 'ntoskrnl.MmMapIoSpace', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmaplockedpages':( 'int', None, 'stdcall', 'ntoskrnl.MmMapLockedPages', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.mmmaplockedpagesspecifycache':( 'int', None, 'stdcall', 'ntoskrnl.MmMapLockedPagesSpecifyCache', (('void *', 'ptr'), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmaplockedpageswithreservedmapping':( 'int', None, 'stdcall', 'ntoskrnl.MmMapLockedPagesWithReservedMapping', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmapmemorydumpmdl':( 'int', None, 'stdcall', 'ntoskrnl.MmMapMemoryDumpMdl', (('void *', 'ptr'),) ),
    'ntoskrnl.mmmapuseraddressestopage':( 'int', None, 'stdcall', 'ntoskrnl.MmMapUserAddressesToPage', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmapvideodisplay':( 'int', None, 'stdcall', 'ntoskrnl.MmMapVideoDisplay', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmapviewinsessionspace':( 'int', None, 'stdcall', 'ntoskrnl.MmMapViewInSessionSpace', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmapviewinsystemspace':( 'int', None, 'stdcall', 'ntoskrnl.MmMapViewInSystemSpace', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmapviewofsection':( 'int', None, 'stdcall', 'ntoskrnl.MmMapViewOfSection', (('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmmarkphysicalmemoryasbad':( 'int', None, 'stdcall', 'ntoskrnl.MmMarkPhysicalMemoryAsBad', (('int', None), ('int', None)) ),
    'ntoskrnl.mmmarkphysicalmemoryasgood':( 'int', None, 'stdcall', 'ntoskrnl.MmMarkPhysicalMemoryAsGood', (('int', None), ('int', None)) ),
    'ntoskrnl.mmpageentiredriver':( 'int', None, 'stdcall', 'ntoskrnl.MmPageEntireDriver', (('int', None),) ),
    'ntoskrnl.mmprefetchpages':( 'int', None, 'stdcall', 'ntoskrnl.MmPrefetchPages', (('int', None), ('int', None)) ),
    'ntoskrnl.mmprobeandlockpages':( 'int', None, 'stdcall', 'ntoskrnl.MmProbeAndLockPages', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.mmprobeandlockprocesspages':( 'int', None, 'stdcall', 'ntoskrnl.MmProbeAndLockProcessPages', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmprobeandlockselectedpages':( 'int', None, 'stdcall', 'ntoskrnl.MmProbeAndLockSelectedPages', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmprotectmdlsystemaddress':( 'int', None, 'stdcall', 'ntoskrnl.MmProtectMdlSystemAddress', (('int', None), ('int', None)) ),
    'ntoskrnl.mmquerysystemsize':( 'int', None, 'cdecl', 'ntoskrnl.MmQuerySystemSize', () ),
    'ntoskrnl.mmremovephysicalmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmRemovePhysicalMemory', (('int', None), ('int', None)) ),
    'ntoskrnl.mmresetdriverpaging':( 'int', None, 'stdcall', 'ntoskrnl.MmResetDriverPaging', (('int', None),) ),
    'ntoskrnl.mmsectionobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.MmSectionObjectType', () ),
    'ntoskrnl.mmsecurevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmSecureVirtualMemory', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmsetaddressrangemodified':( 'int', None, 'stdcall', 'ntoskrnl.MmSetAddressRangeModified', (('int', None), ('int', None)) ),
    'ntoskrnl.mmsetbankedsection':( 'int', None, 'stdcall', 'ntoskrnl.MmSetBankedSection', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.mmsizeofmdl':( 'int', None, 'stdcall', 'ntoskrnl.MmSizeOfMdl', (('int', None), ('int', None)) ),
    'ntoskrnl.mmsystemrangestart':( 'int', None, 'cdecl', 'ntoskrnl.MmSystemRangeStart', () ),
    'ntoskrnl.mmtrimallsystempagablememory':( 'int', None, 'stdcall', 'ntoskrnl.MmTrimAllSystemPagableMemory', (('int', None),) ),
    'ntoskrnl.mmunlockpagableimagesection':( 'int', None, 'stdcall', 'ntoskrnl.MmUnlockPagableImageSection', (('int', None),) ),
    'ntoskrnl.mmunlockpages':( 'int', None, 'stdcall', 'ntoskrnl.MmUnlockPages', (('void *', 'ptr'),) ),
    'ntoskrnl.mmunmapiospace':( 'int', None, 'stdcall', 'ntoskrnl.MmUnmapIoSpace', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.mmunmaplockedpages':( 'int', None, 'stdcall', 'ntoskrnl.MmUnmapLockedPages', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.mmunmapreservedmapping':( 'int', None, 'stdcall', 'ntoskrnl.MmUnmapReservedMapping', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.mmunmapvideodisplay':( 'int', None, 'stdcall', 'ntoskrnl.MmUnmapVideoDisplay', (('int', None), ('int', None)) ),
    'ntoskrnl.mmunmapviewinsessionspace':( 'int', None, 'thiscall', 'ntoskrnl.MmUnmapViewInSessionSpace', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.mmunmapviewinsystemspace':( 'int', None, 'thiscall', 'ntoskrnl.MmUnmapViewInSystemSpace', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.mmunmapviewofsection':( 'int', None, 'stdcall', 'ntoskrnl.MmUnmapViewOfSection', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.mmunsecurevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.MmUnsecureVirtualMemory', (('void *', 'ptr'),) ),
    'ntoskrnl.mmuserprobeaddress':( 'int', None, 'cdecl', 'ntoskrnl.MmUserProbeAddress', () ),
    'ntoskrnl.nlsansicodepage':( 'int', None, 'cdecl', 'ntoskrnl.NlsAnsiCodePage', () ),
    'ntoskrnl.nlsleadbyteinfo':( 'int', None, 'cdecl', 'ntoskrnl.NlsLeadByteInfo', () ),
    'ntoskrnl.nlsmbcodepagetag':( 'int', None, 'cdecl', 'ntoskrnl.NlsMbCodePageTag', () ),
    'ntoskrnl.nlsmboemcodepagetag':( 'int', None, 'cdecl', 'ntoskrnl.NlsMbOemCodePageTag', () ),
    'ntoskrnl.nlsoemcodepage':( 'int', None, 'cdecl', 'ntoskrnl.NlsOemCodePage', () ),
    'ntoskrnl.nlsoemleadbyteinfo':( 'int', None, 'cdecl', 'ntoskrnl.NlsOemLeadByteInfo', () ),
    'ntoskrnl.ntaddatom':( 'int', None, 'stdcall', 'ntoskrnl.NtAddAtom', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntadjustprivilegestoken':( 'int', None, 'stdcall', 'ntoskrnl.NtAdjustPrivilegesToken', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntallocatelocallyuniqueid':( 'int', None, 'stdcall', 'ntoskrnl.NtAllocateLocallyUniqueId', (('void *', 'ptr'),) ),
    'ntoskrnl.ntallocateuuids':( 'int', None, 'stdcall', 'ntoskrnl.NtAllocateUuids', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntallocatevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.NtAllocateVirtualMemory', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntbuildnumber':( 'int', None, 'cdecl', 'ntoskrnl.NtBuildNumber', () ),
    'ntoskrnl.ntclose':( 'int', None, 'stdcall', 'ntoskrnl.NtClose', (('int', None),) ),
    'ntoskrnl.ntconnectport':( 'int', None, 'stdcall', 'ntoskrnl.NtConnectPort', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntcreateevent':( 'int', None, 'stdcall', 'ntoskrnl.NtCreateEvent', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntcreatefile':( 'int', None, 'stdcall', 'ntoskrnl.NtCreateFile', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ntcreatesection':( 'int', None, 'stdcall', 'ntoskrnl.NtCreateSection', (('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntdeleteatom':( 'int', None, 'stdcall', 'ntoskrnl.NtDeleteAtom', (('int', None),) ),
    'ntoskrnl.ntdeletefile':( 'int', None, 'stdcall', 'ntoskrnl.NtDeleteFile', (('void *', 'ptr'),) ),
    'ntoskrnl.ntdeviceiocontrolfile':( 'int', None, 'stdcall', 'ntoskrnl.NtDeviceIoControlFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntduplicateobject':( 'int', None, 'stdcall', 'ntoskrnl.NtDuplicateObject', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntduplicatetoken':( 'int', None, 'stdcall', 'ntoskrnl.NtDuplicateToken', (('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntfindatom':( 'int', None, 'stdcall', 'ntoskrnl.NtFindAtom', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntfreevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.NtFreeVirtualMemory', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntfscontrolfile':( 'int', None, 'stdcall', 'ntoskrnl.NtFsControlFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntglobalflag':( 'int', None, 'cdecl', 'ntoskrnl.NtGlobalFlag', () ),
    'ntoskrnl.ntlockfile':( 'int', None, 'stdcall', 'ntoskrnl.NtLockFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntmakepermanentobject':( 'int', None, 'msfastcall', 'ntoskrnl.NtMakePermanentObject', (('int', None), ('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ntmapviewofsection':( 'int', None, 'stdcall', 'ntoskrnl.NtMapViewOfSection', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntnotifychangedirectoryfile':( 'int', None, 'stdcall', 'ntoskrnl.NtNotifyChangeDirectoryFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntopenfile':( 'int', None, 'stdcall', 'ntoskrnl.NtOpenFile', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntopenprocess':( 'int', None, 'msfastcall', 'ntoskrnl.NtOpenProcess', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntopenprocesstoken':( 'int', None, 'thiscall', 'ntoskrnl.NtOpenProcessToken', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntopenprocesstokenex':( 'int', None, 'thiscall', 'ntoskrnl.NtOpenProcessTokenEx', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntopenthread':( 'int', None, 'msfastcall', 'ntoskrnl.NtOpenThread', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.ntopenthreadtoken':( 'int', None, 'thiscall', 'ntoskrnl.NtOpenThreadToken', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntopenthreadtokenex':( 'int', None, 'thiscall', 'ntoskrnl.NtOpenThreadTokenEx', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntquerydirectoryfile':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryDirectoryFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryeafile':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryEaFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryinformationatom':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryInformationAtom', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryInformationFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryinformationprocess':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryInformationProcess', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryinformationthread':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryInformationThread', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryinformationtoken':( 'int', None, 'msfastcall', 'ntoskrnl.NtQueryInformationToken', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntqueryquotainformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryQuotaInformationFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntquerysecurityobject':( 'int', None, 'stdcall', 'ntoskrnl.NtQuerySecurityObject', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ntquerysysteminformation':( 'int', None, 'stdcall', 'ntoskrnl.NtQuerySystemInformation', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ntqueryvolumeinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtQueryVolumeInformationFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntreadfile':( 'int', None, 'stdcall', 'ntoskrnl.NtReadFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntrequestport':( 'int', None, 'stdcall', 'ntoskrnl.NtRequestPort', (('int', None), ('int', None)) ),
    'ntoskrnl.ntrequestwaitreplyport':( 'int', None, 'stdcall', 'ntoskrnl.NtRequestWaitReplyPort', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntseteafile':( 'int', None, 'stdcall', 'ntoskrnl.NtSetEaFile', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntsetevent':( 'int', None, 'stdcall', 'ntoskrnl.NtSetEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.ntsetinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtSetInformationFile', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntsetinformationprocess':( 'int', None, 'stdcall', 'ntoskrnl.NtSetInformationProcess', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntsetinformationthread':( 'int', None, 'stdcall', 'ntoskrnl.NtSetInformationThread', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ntsetquotainformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtSetQuotaInformationFile', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntsetsecurityobject':( 'int', None, 'stdcall', 'ntoskrnl.NtSetSecurityObject', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.ntsetvolumeinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.NtSetVolumeInformationFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntshutdownsystem':( 'int', None, 'msfastcall', 'ntoskrnl.NtShutdownSystem', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.nttraceevent':( 'int', None, 'stdcall', 'ntoskrnl.NtTraceEvent', (('int', None), ('int', None), ('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ntunlockfile':( 'int', None, 'stdcall', 'ntoskrnl.NtUnlockFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.ntvdmcontrol':( 'int', None, 'thiscall', 'ntoskrnl.NtVdmControl', (('void *', 'obj'), ('int', None), ('void *', 'obj')) ),
    'ntoskrnl.ntwaitforsingleobject':( 'int', None, 'stdcall', 'ntoskrnl.NtWaitForSingleObject', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.ntwritefile':( 'int', None, 'stdcall', 'ntoskrnl.NtWriteFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obassignsecurity':( 'int', None, 'stdcall', 'ntoskrnl.ObAssignSecurity', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obcheckcreateobjectaccess':( 'int', None, 'stdcall', 'ntoskrnl.ObCheckCreateObjectAccess', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obcheckobjectaccess':( 'int', None, 'stdcall', 'ntoskrnl.ObCheckObjectAccess', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obclosehandle':( 'int', None, 'stdcall', 'ntoskrnl.ObCloseHandle', (('int', None), ('int', None)) ),
    'ntoskrnl.obcreateobject':( 'int', None, 'stdcall', 'ntoskrnl.ObCreateObject', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obcreateobjecttype':( 'int', None, 'stdcall', 'ntoskrnl.ObCreateObjectType', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.obdereferenceobject':( 'int', None, 'stdcall', 'ntoskrnl.ObDereferenceObject', (('void *', 'obj'),) ),
    'ntoskrnl.obdereferencesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.ObDereferenceSecurityDescriptor', (('int', None), ('int', None)) ),
    'ntoskrnl.obfindhandleforobject':( 'int', None, 'stdcall', 'ntoskrnl.ObFindHandleForObject', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obgetobjectsecurity':( 'int', None, 'stdcall', 'ntoskrnl.ObGetObjectSecurity', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.obinsertobject':( 'int', None, 'stdcall', 'ntoskrnl.ObInsertObject', (('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.obisdosdevicelocallymapped':( 'int', None, 'stdcall', 'ntoskrnl.ObIsDosDeviceLocallyMapped', (('int', None), ('int', None)) ),
    'ntoskrnl.oblogsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.ObLogSecurityDescriptor', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.obmaketemporaryobject':( 'int', None, 'stdcall', 'ntoskrnl.ObMakeTemporaryObject', (('void *', 'ptr'),) ),
    'ntoskrnl.obopenobjectbyname':( 'int', None, 'stdcall', 'ntoskrnl.ObOpenObjectByName', (('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.obopenobjectbypointer':( 'int', None, 'stdcall', 'ntoskrnl.ObOpenObjectByPointer', (('void *', 'obj'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obquerynamestring':( 'int', None, 'stdcall', 'ntoskrnl.ObQueryNameString', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obqueryobjectauditingbyhandle':( 'int', None, 'stdcall', 'ntoskrnl.ObQueryObjectAuditingByHandle', (('int', None), ('int', None)) ),
    'ntoskrnl.obreferenceobjectbyhandle':( 'int', None, 'stdcall', 'ntoskrnl.ObReferenceObjectByHandle', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.obreferenceobjectbyname':( 'int', None, 'stdcall', 'ntoskrnl.ObReferenceObjectByName', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.obreferenceobjectbypointer':( 'int', None, 'stdcall', 'ntoskrnl.ObReferenceObjectByPointer', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obreferencesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.ObReferenceSecurityDescriptor', (('int', None), ('int', None)) ),
    'ntoskrnl.obreleaseobjectsecurity':( 'int', None, 'stdcall', 'ntoskrnl.ObReleaseObjectSecurity', (('int', None), ('int', None)) ),
    'ntoskrnl.obsethandleattributes':( 'int', None, 'stdcall', 'ntoskrnl.ObSetHandleAttributes', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obsetsecuritydescriptorinfo':( 'int', None, 'stdcall', 'ntoskrnl.ObSetSecurityDescriptorInfo', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obsetsecurityobjectbypointer':( 'int', None, 'stdcall', 'ntoskrnl.ObSetSecurityObjectByPointer', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.obfdereferenceobject':( 'int', None, 'thiscall', 'ntoskrnl.ObfDereferenceObject', (('void *', 'obj'),) ),
    'ntoskrnl.obfreferenceobject':( 'int', None, 'thiscall', 'ntoskrnl.ObfReferenceObject', (('void *', 'obj'),) ),
    'ntoskrnl.pfxfindprefix':( 'int', None, 'stdcall', 'ntoskrnl.PfxFindPrefix', (('int', None), ('int', None)) ),
    'ntoskrnl.pfxinitialize':( 'int', None, 'stdcall', 'ntoskrnl.PfxInitialize', (('int', None),) ),
    'ntoskrnl.pfxinsertprefix':( 'int', None, 'stdcall', 'ntoskrnl.PfxInsertPrefix', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.pfxremoveprefix':( 'int', None, 'stdcall', 'ntoskrnl.PfxRemovePrefix', (('int', None), ('int', None)) ),
    'ntoskrnl.pocalldriver':( 'int', None, 'stdcall', 'ntoskrnl.PoCallDriver', (('int', None), ('int', None)) ),
    'ntoskrnl.pocanceldevicenotify':( 'int', None, 'stdcall', 'ntoskrnl.PoCancelDeviceNotify', (('void *', 'ptr'),) ),
    'ntoskrnl.poqueueshutdownworkitem':( 'int', None, 'stdcall', 'ntoskrnl.PoQueueShutdownWorkItem', (('int', None),) ),
    'ntoskrnl.poregisterdeviceforidledetection':( 'int', None, 'stdcall', 'ntoskrnl.PoRegisterDeviceForIdleDetection', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.poregisterdevicenotify':( 'int', None, 'stdcall', 'ntoskrnl.PoRegisterDeviceNotify', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.poregistersystemstate':( 'int', None, 'stdcall', 'ntoskrnl.PoRegisterSystemState', (('int', None), ('int', None)) ),
    'ntoskrnl.porequestpowerirp':( 'int', None, 'stdcall', 'ntoskrnl.PoRequestPowerIrp', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.porequestshutdownevent':( 'int', None, 'stdcall', 'ntoskrnl.PoRequestShutdownEvent', (('int', None),) ),
    'ntoskrnl.posethiberrange':( 'int', None, 'stdcall', 'ntoskrnl.PoSetHiberRange', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.posetpowerstate':( 'int', None, 'stdcall', 'ntoskrnl.PoSetPowerState', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.posetsystemstate':( 'int', None, 'stdcall', 'ntoskrnl.PoSetSystemState', (('int', None),) ),
    'ntoskrnl.poshutdownbugcheck':( 'int', None, 'thiscall', 'ntoskrnl.PoShutdownBugCheck', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.postartnextpowerirp':( 'int', None, 'stdcall', 'ntoskrnl.PoStartNextPowerIrp', (('int', None),) ),
    'ntoskrnl.pounregistersystemstate':( 'int', None, 'stdcall', 'ntoskrnl.PoUnregisterSystemState', (('void *', 'ptr'),) ),
    'ntoskrnl.probeforread':( 'int', None, 'stdcall', 'ntoskrnl.ProbeForRead', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.probeforwrite':( 'int', None, 'stdcall', 'ntoskrnl.ProbeForWrite', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psassignimpersonationtoken':( 'int', None, 'stdcall', 'ntoskrnl.PsAssignImpersonationToken', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.pschargepoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsChargePoolQuota', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.pschargeprocessnonpagedpoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsChargeProcessNonPagedPoolQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.pschargeprocesspagedpoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsChargeProcessPagedPoolQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.pschargeprocesspoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsChargeProcessPoolQuota', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.pscreatesystemprocess':( 'int', None, 'stdcall', 'ntoskrnl.PsCreateSystemProcess', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.pscreatesystemthread':( 'int', None, 'stdcall', 'ntoskrnl.PsCreateSystemThread', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.psdereferenceimpersonationtoken':( 'int', None, 'stdcall', 'ntoskrnl.PsDereferenceImpersonationToken', (('void *', 'obj'),) ),
    'ntoskrnl.psdereferenceprimarytoken':( 'int', None, 'stdcall', 'ntoskrnl.PsDereferencePrimaryToken', (('void *', 'obj'),) ),
    'ntoskrnl.psdisableimpersonation':( 'int', None, 'stdcall', 'ntoskrnl.PsDisableImpersonation', (('void *', 'obj'), ('void *', 'ptr')) ),
    'ntoskrnl.psestablishwin32callouts':( 'int', None, 'stdcall', 'ntoskrnl.PsEstablishWin32Callouts', (('int', None),) ),
    'ntoskrnl.psgetcontextthread':( 'int', None, 'stdcall', 'ntoskrnl.PsGetContextThread', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psgetcurrentprocess':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentProcess', () ),
    'ntoskrnl.psgetcurrentprocessid':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentProcessId', () ),
    'ntoskrnl.psgetcurrentprocesssessionid':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentProcessSessionId', () ),
    'ntoskrnl.psgetcurrentthread':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentThread', () ),
    'ntoskrnl.psgetcurrentthreadid':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentThreadId', () ),
    'ntoskrnl.psgetcurrentthreadpreviousmode':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentThreadPreviousMode', () ),
    'ntoskrnl.psgetcurrentthreadstackbase':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentThreadStackBase', () ),
    'ntoskrnl.psgetcurrentthreadstacklimit':( 'int', None, 'cdecl', 'ntoskrnl.PsGetCurrentThreadStackLimit', () ),
    'ntoskrnl.psgetjoblock':( 'int', None, 'stdcall', 'ntoskrnl.PsGetJobLock', (('int', None),) ),
    'ntoskrnl.psgetjobsessionid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetJobSessionId', (('int', None),) ),
    'ntoskrnl.psgetjobuirestrictionsclass':( 'int', None, 'stdcall', 'ntoskrnl.PsGetJobUIRestrictionsClass', (('int', None),) ),
    'ntoskrnl.psgetprocesscreatetimequadpart':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessCreateTimeQuadPart', (('int', None),) ),
    'ntoskrnl.psgetprocessdebugport':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessDebugPort', (('int', None),) ),
    'ntoskrnl.psgetprocessexitprocesscalled':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessExitProcessCalled', (('int', None),) ),
    'ntoskrnl.psgetprocessexitstatus':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessExitStatus', (('int', None),) ),
    'ntoskrnl.psgetprocessexittime':( 'int', None, 'cdecl', 'ntoskrnl.PsGetProcessExitTime', () ),
    'ntoskrnl.psgetprocessid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessId', (('int', None),) ),
    'ntoskrnl.psgetprocessimagefilename':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessImageFileName', (('int', None),) ),
    'ntoskrnl.psgetprocessinheritedfromuniqueprocessid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessInheritedFromUniqueProcessId', (('int', None),) ),
    'ntoskrnl.psgetprocessjob':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessJob', (('int', None),) ),
    'ntoskrnl.psgetprocesspeb':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessPeb', (('int', None),) ),
    'ntoskrnl.psgetprocesspriorityclass':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessPriorityClass', (('int', None),) ),
    'ntoskrnl.psgetprocesssectionbaseaddress':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessSectionBaseAddress', (('int', None),) ),
    'ntoskrnl.psgetprocesssecurityport':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessSecurityPort', (('int', None),) ),
    'ntoskrnl.psgetprocesssessionid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessSessionId', (('int', None),) ),
    'ntoskrnl.psgetprocesswin32process':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessWin32Process', (('int', None),) ),
    'ntoskrnl.psgetprocesswin32windowstation':( 'int', None, 'stdcall', 'ntoskrnl.PsGetProcessWin32WindowStation', (('int', None),) ),
    'ntoskrnl.psgetthreadfreezecount':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadFreezeCount', (('int', None),) ),
    'ntoskrnl.psgetthreadharderrorsaredisabled':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadHardErrorsAreDisabled', (('int', None),) ),
    'ntoskrnl.psgetthreadid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadId', (('int', None),) ),
    'ntoskrnl.psgetthreadprocess':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadProcess', (('int', None),) ),
    'ntoskrnl.psgetthreadprocessid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadProcessId', (('int', None),) ),
    'ntoskrnl.psgetthreadsessionid':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadSessionId', (('int', None),) ),
    'ntoskrnl.psgetthreadteb':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadTeb', (('int', None),) ),
    'ntoskrnl.psgetthreadwin32thread':( 'int', None, 'stdcall', 'ntoskrnl.PsGetThreadWin32Thread', (('int', None),) ),
    'ntoskrnl.psgetversion':( 'int', None, 'stdcall', 'ntoskrnl.PsGetVersion', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psimpersonateclient':( 'int', None, 'stdcall', 'ntoskrnl.PsImpersonateClient', (('void *', 'obj'), ('void *', 'obj'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psinitialsystemprocess':( 'int', None, 'cdecl', 'ntoskrnl.PsInitialSystemProcess', () ),
    'ntoskrnl.psisprocessbeingdebugged':( 'int', None, 'stdcall', 'ntoskrnl.PsIsProcessBeingDebugged', (('int', None),) ),
    'ntoskrnl.psissystemthread':( 'int', None, 'stdcall', 'ntoskrnl.PsIsSystemThread', (('int', None),) ),
    'ntoskrnl.psisthreadimpersonating':( 'int', None, 'stdcall', 'ntoskrnl.PsIsThreadImpersonating', (('int', None),) ),
    'ntoskrnl.psisthreadterminating':( 'int', None, 'stdcall', 'ntoskrnl.PsIsThreadTerminating', (('int', None),) ),
    'ntoskrnl.psjobtype':( 'int', None, 'cdecl', 'ntoskrnl.PsJobType', () ),
    'ntoskrnl.pslookupprocessbyprocessid':( 'int', None, 'stdcall', 'ntoskrnl.PsLookupProcessByProcessId', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.pslookupprocessthreadbycid':( 'int', None, 'stdcall', 'ntoskrnl.PsLookupProcessThreadByCid', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.pslookupthreadbythreadid':( 'int', None, 'stdcall', 'ntoskrnl.PsLookupThreadByThreadId', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.psprocesstype':( 'int', None, 'cdecl', 'ntoskrnl.PsProcessType', () ),
    'ntoskrnl.psreferenceimpersonationtoken':( 'int', None, 'stdcall', 'ntoskrnl.PsReferenceImpersonationToken', (('void *', 'obj'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.psreferenceprimarytoken':( 'int', None, 'stdcall', 'ntoskrnl.PsReferencePrimaryToken', (('void *', 'obj'),) ),
    'ntoskrnl.psremovecreatethreadnotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsRemoveCreateThreadNotifyRoutine', (('int', None),) ),
    'ntoskrnl.psremoveloadimagenotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsRemoveLoadImageNotifyRoutine', (('int', None),) ),
    'ntoskrnl.psrestoreimpersonation':( 'int', None, 'stdcall', 'ntoskrnl.PsRestoreImpersonation', (('void *', 'obj'), ('void *', 'ptr')) ),
    'ntoskrnl.psreturnpoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsReturnPoolQuota', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psreturnprocessnonpagedpoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsReturnProcessNonPagedPoolQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.psreturnprocesspagedpoolquota':( 'int', None, 'stdcall', 'ntoskrnl.PsReturnProcessPagedPoolQuota', (('int', None), ('int', None)) ),
    'ntoskrnl.psrevertthreadtoself':( 'int', None, 'stdcall', 'ntoskrnl.PsRevertThreadToSelf', (('void *', 'obj'),) ),
    'ntoskrnl.psreverttoself':( 'int', None, 'cdecl', 'ntoskrnl.PsRevertToSelf', () ),
    'ntoskrnl.pssetcontextthread':( 'int', None, 'stdcall', 'ntoskrnl.PsSetContextThread', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.pssetcreateprocessnotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsSetCreateProcessNotifyRoutine', (('void *', 'funcptr'), ('int', None)) ),
    'ntoskrnl.pssetcreatethreadnotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsSetCreateThreadNotifyRoutine', (('void * ', 'funcptr'),) ),
    'ntoskrnl.pssetjobuirestrictionsclass':( 'int', None, 'stdcall', 'ntoskrnl.PsSetJobUIRestrictionsClass', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetlegonotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsSetLegoNotifyRoutine', (('int', None),) ),
    'ntoskrnl.pssetloadimagenotifyroutine':( 'int', None, 'stdcall', 'ntoskrnl.PsSetLoadImageNotifyRoutine', (('void *', 'funcptr'),) ),
    'ntoskrnl.pssetprocessprioritybyclass':( 'int', None, 'stdcall', 'ntoskrnl.PsSetProcessPriorityByClass', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetprocesspriorityclass':( 'int', None, 'stdcall', 'ntoskrnl.PsSetProcessPriorityClass', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetprocesssecurityport':( 'int', None, 'stdcall', 'ntoskrnl.PsSetProcessSecurityPort', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetprocesswin32process':( 'int', None, 'stdcall', 'ntoskrnl.PsSetProcessWin32Process', (('void *', 'obj'), ('int', None), ('int', None)) ),
    'ntoskrnl.pssetprocesswindowstation':( 'int', None, 'stdcall', 'ntoskrnl.PsSetProcessWindowStation', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetthreadharderrorsaredisabled':( 'int', None, 'stdcall', 'ntoskrnl.PsSetThreadHardErrorsAreDisabled', (('int', None), ('int', None)) ),
    'ntoskrnl.pssetthreadwin32thread':( 'int', None, 'stdcall', 'ntoskrnl.PsSetThreadWin32Thread', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.psterminatesystemthread':( 'int', None, 'stdcall', 'ntoskrnl.PsTerminateSystemThread', (('int', None),) ),
    'ntoskrnl.psthreadtype':( 'int', None, 'cdecl', 'ntoskrnl.PsThreadType', () ),
    'ntoskrnl.read_register_buffer_uchar':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_BUFFER_UCHAR', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.read_register_buffer_ulong':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_BUFFER_ULONG', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.read_register_buffer_ushort':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_BUFFER_USHORT', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.read_register_uchar':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_UCHAR', (('int', None),) ),
    'ntoskrnl.read_register_ulong':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_ULONG', (('int', None),) ),
    'ntoskrnl.read_register_ushort':( 'int', None, 'stdcall', 'ntoskrnl.READ_REGISTER_USHORT', (('int', None),) ),
    'ntoskrnl.rtlabsolutetoselfrelativesd':( 'int', None, 'stdcall', 'ntoskrnl.RtlAbsoluteToSelfRelativeSD', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtladdaccessallowedace':( 'int', None, 'stdcall', 'ntoskrnl.RtlAddAccessAllowedAce', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtladdaccessallowedaceex':( 'int', None, 'stdcall', 'ntoskrnl.RtlAddAccessAllowedAceEx', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtladdace':( 'int', None, 'stdcall', 'ntoskrnl.RtlAddAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtladdatomtoatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlAddAtomToAtomTable', (('void *', 'obj'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtladdrange':( 'int', None, 'stdcall', 'ntoskrnl.RtlAddRange', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlallocateheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlAllocateHeap', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlansichartounicodechar':( 'int', None, 'stdcall', 'ntoskrnl.RtlAnsiCharToUnicodeChar', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlansistringtounicodesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlAnsiStringToUnicodeSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlansistringtounicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlAnsiStringToUnicodeString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlappendasciiztostring':( 'int', None, 'stdcall', 'ntoskrnl.RtlAppendAsciizToString', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlappendstringtostring':( 'int', None, 'stdcall', 'ntoskrnl.RtlAppendStringToString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlappendunicodestringtostring':( 'int', None, 'stdcall', 'ntoskrnl.RtlAppendUnicodeStringToString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlappendunicodetostring':( 'int', None, 'stdcall', 'ntoskrnl.RtlAppendUnicodeToString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlareallaccessesgranted':( 'int', None, 'stdcall', 'ntoskrnl.RtlAreAllAccessesGranted', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlareanyaccessesgranted':( 'int', None, 'stdcall', 'ntoskrnl.RtlAreAnyAccessesGranted', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlarebitsclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlAreBitsClear', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlarebitsset':( 'int', None, 'stdcall', 'ntoskrnl.RtlAreBitsSet', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlassert':( 'int', None, 'stdcall', 'ntoskrnl.RtlAssert', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcapturecontext':( 'int', None, 'stdcall', 'ntoskrnl.RtlCaptureContext', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlcapturestackbacktrace':( 'int', None, 'stdcall', 'ntoskrnl.RtlCaptureStackBackTrace', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlchartointeger':( 'int', None, 'stdcall', 'ntoskrnl.RtlCharToInteger', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlcheckregistrykey':( 'int', None, 'stdcall', 'ntoskrnl.RtlCheckRegistryKey', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlclearallbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlClearAllBits', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlclearbit':( 'int', None, 'stdcall', 'ntoskrnl.RtlClearBit', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlclearbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlClearBits', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcomparememory':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompareMemory', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlcomparememoryulong':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompareMemoryUlong', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcomparestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompareString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcompareunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompareUnicodeString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlcompressbuffer':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompressBuffer', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlcompresschunks':( 'int', None, 'stdcall', 'ntoskrnl.RtlCompressChunks', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlconvertlongtolargeinteger':( 'int', None, 'stdcall', 'ntoskrnl.RtlConvertLongToLargeInteger', (('int', None),) ),
    'ntoskrnl.rtlconvertsidtounicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlConvertSidToUnicodeString', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlconvertulongtolargeinteger':( 'int', None, 'stdcall', 'ntoskrnl.RtlConvertUlongToLargeInteger', (('int', None),) ),
    'ntoskrnl.rtlcopyluid':( 'int', None, 'stdcall', 'ntoskrnl.RtlCopyLuid', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlcopyrangelist':( 'int', None, 'stdcall', 'ntoskrnl.RtlCopyRangeList', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlcopysid':( 'int', None, 'stdcall', 'ntoskrnl.RtlCopySid', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcopystring':( 'int', None, 'stdcall', 'ntoskrnl.RtlCopyString', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlcopyunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlCopyUnicodeString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlcreateacl':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateAcl', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcreateatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateAtomTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlcreateheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateHeap', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlcreateregistrykey':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateRegistryKey', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlcreatesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateSecurityDescriptor', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlcreatesystemvolumeinformationfolder':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateSystemVolumeInformationFolder', (('int', None),) ),
    'ntoskrnl.rtlcreateunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlCreateUnicodeString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlcustomcptounicoden':( 'int', None, 'stdcall', 'ntoskrnl.RtlCustomCPToUnicodeN', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtldecompressbuffer':( 'int', None, 'stdcall', 'ntoskrnl.RtlDecompressBuffer', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtldecompresschunks':( 'int', None, 'stdcall', 'ntoskrnl.RtlDecompressChunks', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtldecompressfragment':( 'int', None, 'stdcall', 'ntoskrnl.RtlDecompressFragment', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtldelete':( 'int', None, 'stdcall', 'ntoskrnl.RtlDelete', (('int', None),) ),
    'ntoskrnl.rtldeleteace':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteAce', (('int', None), ('int', None)) ),
    'ntoskrnl.rtldeleteatomfromatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteAtomFromAtomTable', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.rtldeleteelementgenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteElementGenericTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtldeleteelementgenerictableavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteElementGenericTableAvl', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtldeletenosplay':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteNoSplay', (('int', None), ('int', None)) ),
    'ntoskrnl.rtldeleteownersranges':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteOwnersRanges', (('int', None), ('int', None)) ),
    'ntoskrnl.rtldeleterange':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteRange', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtldeleteregistryvalue':( 'int', None, 'stdcall', 'ntoskrnl.RtlDeleteRegistryValue', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtldescribechunk':( 'int', None, 'stdcall', 'ntoskrnl.RtlDescribeChunk', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtldestroyatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlDestroyAtomTable', (('void *', 'obj'),) ),
    'ntoskrnl.rtldestroyheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlDestroyHeap', (('int', None),) ),
    'ntoskrnl.rtldowncaseunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlDowncaseUnicodeString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlemptyatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlEmptyAtomTable', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.rtlenlargedintegermultiply':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnlargedIntegerMultiply', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlenlargedunsigneddivide':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnlargedUnsignedDivide', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlenlargedunsignedmultiply':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnlargedUnsignedMultiply', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlenumerategenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnumerateGenericTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlenumerategenerictableavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnumerateGenericTableAvl', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlenumerategenerictablelikeadirectory':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnumerateGenericTableLikeADirectory', (('int', None), ('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlenumerategenerictablewithoutsplaying':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnumerateGenericTableWithoutSplaying', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlenumerategenerictablewithoutsplayingavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlEnumerateGenericTableWithoutSplayingAvl', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlequalluid':( 'int', None, 'stdcall', 'ntoskrnl.RtlEqualLuid', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlequalsid':( 'int', None, 'stdcall', 'ntoskrnl.RtlEqualSid', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlequalstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlEqualString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlequalunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlEqualUnicodeString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlextendedintegermultiply':( 'int', None, 'stdcall', 'ntoskrnl.RtlExtendedIntegerMultiply', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlextendedlargeintegerdivide':( 'int', None, 'stdcall', 'ntoskrnl.RtlExtendedLargeIntegerDivide', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlextendedmagicdivide':( 'int', None, 'stdcall', 'ntoskrnl.RtlExtendedMagicDivide', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfillmemory':( 'int', None, 'stdcall', 'ntoskrnl.RtlFillMemory', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfillmemoryulong':( 'int', None, 'stdcall', 'ntoskrnl.RtlFillMemoryUlong', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindclearbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindClearBits', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindclearbitsandset':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindClearBitsAndSet', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindclearruns':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindClearRuns', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindfirstrunclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindFirstRunClear', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlfindlastbackwardrunclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindLastBackwardRunClear', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindleastsignificantbit':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindLeastSignificantBit', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindlongestrunclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindLongestRunClear', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindmessage':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindMessage', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlfindmostsignificantbit':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindMostSignificantBit', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindnextforwardrunclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindNextForwardRunClear', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlfindrange':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindRange', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'ntoskrnl.rtlfindsetbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindSetBits', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindsetbitsandclear':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindSetBitsAndClear', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfindunicodeprefix':( 'int', None, 'stdcall', 'ntoskrnl.RtlFindUnicodePrefix', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlformatcurrentuserkeypath':( 'int', None, 'stdcall', 'ntoskrnl.RtlFormatCurrentUserKeyPath', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlfreeansistring':( 'int', None, 'stdcall', 'ntoskrnl.RtlFreeAnsiString', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlfreeheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlFreeHeap', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlfreeoemstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlFreeOemString', (('int', None),) ),
    'ntoskrnl.rtlfreerangelist':( 'int', None, 'stdcall', 'ntoskrnl.RtlFreeRangeList', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlfreeunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlFreeUnicodeString', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlguidfromstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlGUIDFromString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgenerate8dot3name':( 'int', None, 'stdcall', 'ntoskrnl.RtlGenerate8dot3Name', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetace':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetAce', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetcallersaddress':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetCallersAddress', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetcompressionworkspacesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetCompressionWorkSpaceSize', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetdaclsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetDaclSecurityDescriptor', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetdefaultcodepage':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetDefaultCodePage', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetelementgenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetElementGenericTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetelementgenerictableavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetElementGenericTableAvl', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetfirstrange':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetFirstRange', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetgroupsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetGroupSecurityDescriptor', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetnextrange':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetNextRange', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlgetntglobalflags':( 'int', None, 'cdecl', 'ntoskrnl.RtlGetNtGlobalFlags', () ),
    'ntoskrnl.rtlgetownersecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetOwnerSecurityDescriptor', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetsaclsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetSaclSecurityDescriptor', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlgetsetbootstatusdata':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetSetBootStatusData', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlgetversion':( 'int', None, 'stdcall', 'ntoskrnl.RtlGetVersion', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlhashunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlHashUnicodeString', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlimagedirectoryentrytodata':( 'int', None, 'stdcall', 'ntoskrnl.RtlImageDirectoryEntryToData', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlimagentheader':( 'int', None, 'stdcall', 'ntoskrnl.RtlImageNtHeader', (('int', None),) ),
    'ntoskrnl.rtlinitansistring':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitAnsiString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlinitcodepagetable':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitCodePageTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlinitstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlinitunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitUnicodeString', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlinitializebitmap':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeBitMap', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlinitializegenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeGenericTable', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinitializegenerictableavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeGenericTableAvl', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinitializerangelist':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeRangeList', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlinitializesid':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeSid', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlinitializeunicodeprefix':( 'int', None, 'stdcall', 'ntoskrnl.RtlInitializeUnicodePrefix', (('int', None),) ),
    'ntoskrnl.rtlinsertelementgenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlInsertElementGenericTable', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinsertelementgenerictableavl':( 'int', None, 'thiscall', 'ntoskrnl.RtlInsertElementGenericTableAvl', (('void *', 'obj'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinsertelementgenerictablefull':( 'int', None, 'stdcall', 'ntoskrnl.RtlInsertElementGenericTableFull', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinsertelementgenerictablefullavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlInsertElementGenericTableFullAvl', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlinsertunicodeprefix':( 'int', None, 'stdcall', 'ntoskrnl.RtlInsertUnicodePrefix', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlint64tounicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlInt64ToUnicodeString', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlintegertochar':( 'int', None, 'stdcall', 'ntoskrnl.RtlIntegerToChar', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlintegertounicode':( 'int', None, 'stdcall', 'ntoskrnl.RtlIntegerToUnicode', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlintegertounicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlIntegerToUnicodeString', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlinvertrangelist':( 'int', None, 'stdcall', 'ntoskrnl.RtlInvertRangeList', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4addresstostringa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4AddressToStringA', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlipv4addresstostringexa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4AddressToStringExA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4addresstostringexw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4AddressToStringExW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4addresstostringw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4AddressToStringW', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlipv4stringtoaddressa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4StringToAddressA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4stringtoaddressexa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4StringToAddressExA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4stringtoaddressexw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4StringToAddressExW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv4stringtoaddressw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv4StringToAddressW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv6addresstostringa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6AddressToStringA', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlipv6addresstostringexa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6AddressToStringExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv6addresstostringexw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6AddressToStringExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv6addresstostringw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6AddressToStringW', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlipv6stringtoaddressa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6StringToAddressA', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlipv6stringtoaddressexa':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6StringToAddressExA', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv6stringtoaddressexw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6StringToAddressExW', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlipv6stringtoaddressw':( 'int', None, 'stdcall', 'ntoskrnl.RtlIpv6StringToAddressW', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlisgenerictableempty':( 'int', None, 'stdcall', 'ntoskrnl.RtlIsGenericTableEmpty', (('int', None),) ),
    'ntoskrnl.rtlisgenerictableemptyavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlIsGenericTableEmptyAvl', (('int', None),) ),
    'ntoskrnl.rtlisnamelegaldos8dot3':( 'int', None, 'stdcall', 'ntoskrnl.RtlIsNameLegalDOS8Dot3', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlisrangeavailable':( 'int', None, 'stdcall', 'ntoskrnl.RtlIsRangeAvailable', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'ntoskrnl.rtlisvalidoemcharacter':( 'int', None, 'stdcall', 'ntoskrnl.RtlIsValidOemCharacter', (('int', None),) ),
    'ntoskrnl.rtllargeintegeradd':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerAdd', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegerarithmeticshift':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerArithmeticShift', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegerdivide':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerDivide', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegernegate':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerNegate', (('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegershiftleft':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerShiftLeft', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegershiftright':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerShiftRight', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllargeintegersubtract':( 'int', None, 'stdcall', 'ntoskrnl.RtlLargeIntegerSubtract', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllengthrequiredsid':( 'int', None, 'stdcall', 'ntoskrnl.RtlLengthRequiredSid', (('int', None),) ),
    'ntoskrnl.rtllengthsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlLengthSecurityDescriptor', (('int', None),) ),
    'ntoskrnl.rtllengthsid':( 'int', None, 'stdcall', 'ntoskrnl.RtlLengthSid', (('void *', 'ptr'),) ),
    'ntoskrnl.rtllockbootstatusdata':( 'int', None, 'stdcall', 'ntoskrnl.RtlLockBootStatusData', (('void *', 'ptr'),) ),
    'ntoskrnl.rtllookupatominatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlLookupAtomInAtomTable', (('void *', 'obj'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtllookupelementgenerictable':( 'int', None, 'stdcall', 'ntoskrnl.RtlLookupElementGenericTable', (('int', None), ('int', None)) ),
    'ntoskrnl.rtllookupelementgenerictableavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlLookupElementGenericTableAvl', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtllookupelementgenerictablefull':( 'int', None, 'stdcall', 'ntoskrnl.RtlLookupElementGenericTableFull', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtllookupelementgenerictablefullavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlLookupElementGenericTableFullAvl', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlmapgenericmask':( 'int', None, 'stdcall', 'ntoskrnl.RtlMapGenericMask', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlmapsecurityerrortontstatus':( 'int', None, 'stdcall', 'ntoskrnl.RtlMapSecurityErrorToNtStatus', (('int', None),) ),
    'ntoskrnl.rtlmergerangelists':( 'int', None, 'stdcall', 'ntoskrnl.RtlMergeRangeLists', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlmovememory':( 'int', None, 'stdcall', 'ntoskrnl.RtlMoveMemory', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlmultibytetounicoden':( 'int', None, 'stdcall', 'ntoskrnl.RtlMultiByteToUnicodeN', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlmultibytetounicodesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlMultiByteToUnicodeSize', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlnextunicodeprefix':( 'int', None, 'stdcall', 'ntoskrnl.RtlNextUnicodePrefix', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlntstatustodoserror':( 'int', None, 'stdcall', 'ntoskrnl.RtlNtStatusToDosError', (('int', None),) ),
    'ntoskrnl.rtlntstatustodoserrornoteb':( 'int', None, 'stdcall', 'ntoskrnl.RtlNtStatusToDosErrorNoTeb', (('int', None),) ),
    'ntoskrnl.rtlnumbergenerictableelements':( 'int', None, 'stdcall', 'ntoskrnl.RtlNumberGenericTableElements', (('int', None),) ),
    'ntoskrnl.rtlnumbergenerictableelementsavl':( 'int', None, 'stdcall', 'ntoskrnl.RtlNumberGenericTableElementsAvl', (('int', None),) ),
    'ntoskrnl.rtlnumberofclearbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlNumberOfClearBits', (('int', None),) ),
    'ntoskrnl.rtlnumberofsetbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlNumberOfSetBits', (('void *', 'ptr'),) ),
    'ntoskrnl.rtloemstringtocountedunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlOemStringToCountedUnicodeString', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtloemstringtounicodesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlOemStringToUnicodeSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtloemstringtounicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlOemStringToUnicodeString', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtloemtounicoden':( 'int', None, 'stdcall', 'ntoskrnl.RtlOemToUnicodeN', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlpinatominatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlPinAtomInAtomTable', (('void *', 'obj'), ('int', None)) ),
    'ntoskrnl.rtlprefetchmemorynontemporal':( 'int', None, 'cdecl', 'ntoskrnl.RtlPrefetchMemoryNonTemporal', () ),
    'ntoskrnl.rtlprefixstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlPrefixString', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlprefixunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlPrefixUnicodeString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlqueryatominatomtable':( 'int', None, 'stdcall', 'ntoskrnl.RtlQueryAtomInAtomTable', (('void *', 'obj'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlqueryregistryvalues':( 'int', None, 'stdcall', 'ntoskrnl.RtlQueryRegistryValues', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlquerytimezoneinformation':( 'int', None, 'stdcall', 'ntoskrnl.RtlQueryTimeZoneInformation', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlraiseexception':( 'int', None, 'cdecl', 'ntoskrnl.RtlRaiseException', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlrandom':( 'int', None, 'stdcall', 'ntoskrnl.RtlRandom', (('int', None),) ),
    'ntoskrnl.rtlrandomex':( 'int', None, 'stdcall', 'ntoskrnl.RtlRandomEx', (('int', None),) ),
    'ntoskrnl.rtlrealpredecessor':( 'int', None, 'stdcall', 'ntoskrnl.RtlRealPredecessor', (('int', None),) ),
    'ntoskrnl.rtlrealsuccessor':( 'int', None, 'stdcall', 'ntoskrnl.RtlRealSuccessor', (('int', None),) ),
    'ntoskrnl.rtlremoveunicodeprefix':( 'int', None, 'stdcall', 'ntoskrnl.RtlRemoveUnicodePrefix', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlreservechunk':( 'int', None, 'stdcall', 'ntoskrnl.RtlReserveChunk', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlsecondssince1970totime':( 'int', None, 'stdcall', 'ntoskrnl.RtlSecondsSince1970ToTime', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlsecondssince1980totime':( 'int', None, 'stdcall', 'ntoskrnl.RtlSecondsSince1980ToTime', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlselfrelativetoabsolutesd':( 'int', None, 'stdcall', 'ntoskrnl.RtlSelfRelativeToAbsoluteSD', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlselfrelativetoabsolutesd2':( 'int', None, 'stdcall', 'ntoskrnl.RtlSelfRelativeToAbsoluteSD2', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlsetallbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetAllBits', (('int', None),) ),
    'ntoskrnl.rtlsetbit':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetBit', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlsetbits':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetBits', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlsetdaclsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetDaclSecurityDescriptor', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlsetgroupsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetGroupSecurityDescriptor', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlsetownersecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetOwnerSecurityDescriptor', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlsetsaclsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSetSaclSecurityDescriptor', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlsettimezoneinformation':( 'int', None, 'thiscall', 'ntoskrnl.RtlSetTimeZoneInformation', (('void *', 'obj'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlsizeheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlSizeHeap', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlsplay':( 'int', None, 'stdcall', 'ntoskrnl.RtlSplay', (('int', None),) ),
    'ntoskrnl.rtlstringfromguid':( 'int', None, 'stdcall', 'ntoskrnl.RtlStringFromGUID', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtlsubauthoritycountsid':( 'int', None, 'stdcall', 'ntoskrnl.RtlSubAuthorityCountSid', (('int', None),) ),
    'ntoskrnl.rtlsubauthoritysid':( 'int', None, 'stdcall', 'ntoskrnl.RtlSubAuthoritySid', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlsubtreepredecessor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSubtreePredecessor', (('int', None),) ),
    'ntoskrnl.rtlsubtreesuccessor':( 'int', None, 'stdcall', 'ntoskrnl.RtlSubtreeSuccessor', (('int', None),) ),
    'ntoskrnl.rtltestbit':( 'int', None, 'stdcall', 'ntoskrnl.RtlTestBit', (('int', None), ('int', None)) ),
    'ntoskrnl.rtltimefieldstotime':( 'int', None, 'stdcall', 'ntoskrnl.RtlTimeFieldsToTime', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtltimetoelapsedtimefields':( 'int', None, 'msfastcall', 'ntoskrnl.RtlTimeToElapsedTimeFields', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtltimetosecondssince1970':( 'int', None, 'stdcall', 'ntoskrnl.RtlTimeToSecondsSince1970', (('int', None), ('int', None)) ),
    'ntoskrnl.rtltimetosecondssince1980':( 'int', None, 'stdcall', 'ntoskrnl.RtlTimeToSecondsSince1980', (('int', None), ('int', None)) ),
    'ntoskrnl.rtltimetotimefields':( 'int', None, 'msfastcall', 'ntoskrnl.RtlTimeToTimeFields', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.rtltracedatabaseadd':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseAdd', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtltracedatabasecreate':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseCreate', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtltracedatabasedestroy':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseDestroy', (('int', None),) ),
    'ntoskrnl.rtltracedatabaseenumerate':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseEnumerate', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtltracedatabasefind':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseFind', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtltracedatabaselock':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseLock', (('int', None),) ),
    'ntoskrnl.rtltracedatabaseunlock':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseUnlock', (('int', None),) ),
    'ntoskrnl.rtltracedatabasevalidate':( 'int', None, 'stdcall', 'ntoskrnl.RtlTraceDatabaseValidate', (('int', None),) ),
    'ntoskrnl.rtlulongbyteswap':( 'int', None, 'cdecl', 'ntoskrnl.RtlUlongByteSwap', () ),
    'ntoskrnl.rtlulonglongbyteswap':( 'int', None, 'cdecl', 'ntoskrnl.RtlUlonglongByteSwap', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlunicodestringtoansisize':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToAnsiSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlunicodestringtoansistring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToAnsiString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlunicodestringtocountedoemstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToCountedOemString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlunicodestringtointeger':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToInteger', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.rtlunicodestringtooemsize':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToOemSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlunicodestringtooemstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeStringToOemString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlunicodetocustomcpn':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeToCustomCPN', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlunicodetomultibyten':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeToMultiByteN', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlunicodetomultibytesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeToMultiByteSize', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlunicodetooemn':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnicodeToOemN', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlunlockbootstatusdata':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnlockBootStatusData', (('int', None),) ),
    'ntoskrnl.rtlunwind':( 'int', None, 'stdcall', 'ntoskrnl.RtlUnwind', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodechar':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeChar', (('int', None),) ),
    'ntoskrnl.rtlupcaseunicodestring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeString', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodestringtoansistring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeStringToAnsiString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodestringtocountedoemstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeStringToCountedOemString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodestringtooemstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeStringToOemString', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodetocustomcpn':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeToCustomCPN', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodetomultibyten':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeToMultiByteN', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlupcaseunicodetooemn':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpcaseUnicodeToOemN', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlupperchar':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpperChar', (('int', None),) ),
    'ntoskrnl.rtlupperstring':( 'int', None, 'stdcall', 'ntoskrnl.RtlUpperString', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlushortbyteswap':( 'int', None, 'cdecl', 'ntoskrnl.RtlUshortByteSwap', () ),
    'ntoskrnl.rtlvalidrelativesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlValidRelativeSecurityDescriptor', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlvalidsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.RtlValidSecurityDescriptor', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlvalidsid':( 'int', None, 'stdcall', 'ntoskrnl.RtlValidSid', (('int', None),) ),
    'ntoskrnl.rtlverifyversioninfo':( 'int', None, 'stdcall', 'ntoskrnl.RtlVerifyVersionInfo', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlvolumedevicetodosname':( 'int', None, 'stdcall', 'ntoskrnl.RtlVolumeDeviceToDosName', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlwalkframechain':( 'int', None, 'stdcall', 'ntoskrnl.RtlWalkFrameChain', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.rtlwriteregistryvalue':( 'int', None, 'stdcall', 'ntoskrnl.RtlWriteRegistryValue', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.rtlzeroheap':( 'int', None, 'stdcall', 'ntoskrnl.RtlZeroHeap', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlzeromemory':( 'int', None, 'stdcall', 'ntoskrnl.RtlZeroMemory', (('int', None), ('int', None)) ),
    'ntoskrnl.rtlxansistringtounicodesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlxAnsiStringToUnicodeSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlxoemstringtounicodesize':( 'int', None, 'stdcall', 'ntoskrnl.RtlxOemStringToUnicodeSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlxunicodestringtoansisize':( 'int', None, 'stdcall', 'ntoskrnl.RtlxUnicodeStringToAnsiSize', (('void *', 'ptr'),) ),
    'ntoskrnl.rtlxunicodestringtooemsize':( 'int', None, 'stdcall', 'ntoskrnl.RtlxUnicodeStringToOemSize', (('void *', 'ptr'),) ),
    'ntoskrnl.seaccesscheck':( 'int', None, 'stdcall', 'ntoskrnl.SeAccessCheck', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.seappendprivileges':( 'int', None, 'stdcall', 'ntoskrnl.SeAppendPrivileges', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.seassignsecurity':( 'int', None, 'stdcall', 'ntoskrnl.SeAssignSecurity', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.seassignsecurityex':( 'int', None, 'stdcall', 'ntoskrnl.SeAssignSecurityEx', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.seaudithardlinkcreation':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditHardLinkCreation', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.seauditingfileevents':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditingFileEvents', (('int', None), ('int', None)) ),
    'ntoskrnl.seauditingfileeventswithcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditingFileEventsWithContext', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.seauditingfileorglobalevents':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditingFileOrGlobalEvents', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.seauditinghardlinkevents':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditingHardLinkEvents', (('int', None), ('int', None)) ),
    'ntoskrnl.seauditinghardlinkeventswithcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeAuditingHardLinkEventsWithContext', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.secapturesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.SeCaptureSecurityDescriptor', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.secapturesubjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeCaptureSubjectContext', (('void *', 'ptr'),) ),
    'ntoskrnl.secloseobjectauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.SeCloseObjectAuditAlarm', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.secreateaccessstate':( 'int', None, 'stdcall', 'ntoskrnl.SeCreateAccessState', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.secreateclientsecurity':( 'int', None, 'thiscall', 'ntoskrnl.SeCreateClientSecurity', (('void *', 'obj'), ('void *', 'obj'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.secreateclientsecurityfromsubjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeCreateClientSecurityFromSubjectContext', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.sedeassignsecurity':( 'int', None, 'stdcall', 'ntoskrnl.SeDeassignSecurity', (('void *', 'ptr'),) ),
    'ntoskrnl.sedeleteaccessstate':( 'int', None, 'stdcall', 'ntoskrnl.SeDeleteAccessState', (('void *', 'ptr'),) ),
    'ntoskrnl.sedeleteobjectauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.SeDeleteObjectAuditAlarm', (('int', None), ('int', None)) ),
    'ntoskrnl.seexports':( 'int', None, 'cdecl', 'ntoskrnl.SeExports', () ),
    'ntoskrnl.sefiltertoken':( 'int', None, 'stdcall', 'ntoskrnl.SeFilterToken', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.sefreeprivileges':( 'int', None, 'stdcall', 'ntoskrnl.SeFreePrivileges', (('void *', 'ptr'),) ),
    'ntoskrnl.seimpersonateclient':( 'int', None, 'stdcall', 'ntoskrnl.SeImpersonateClient', (('int', None), ('void *', 'obj')) ),
    'ntoskrnl.seimpersonateclientex':( 'int', None, 'stdcall', 'ntoskrnl.SeImpersonateClientEx', (('void *', 'ptr'), ('void *', 'obj')) ),
    'ntoskrnl.selocksubjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeLockSubjectContext', (('void *', 'ptr'),) ),
    'ntoskrnl.semarklogonsessionforterminationnotification':( 'int', None, 'stdcall', 'ntoskrnl.SeMarkLogonSessionForTerminationNotification', (('int', None),) ),
    'ntoskrnl.seopenobjectauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.SeOpenObjectAuditAlarm', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.seopenobjectfordeleteauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.SeOpenObjectForDeleteAuditAlarm', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.seprivilegecheck':( 'int', None, 'stdcall', 'ntoskrnl.SePrivilegeCheck', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.seprivilegeobjectauditalarm':( 'int', None, 'msfastcall', 'ntoskrnl.SePrivilegeObjectAuditAlarm', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.sepublicdefaultdacl':( 'int', None, 'cdecl', 'ntoskrnl.SePublicDefaultDacl', () ),
    'ntoskrnl.sequeryauthenticationidtoken':( 'int', None, 'stdcall', 'ntoskrnl.SeQueryAuthenticationIdToken', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.sequeryinformationtoken':( 'int', None, 'stdcall', 'ntoskrnl.SeQueryInformationToken', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.sequerysecuritydescriptorinfo':( 'int', None, 'stdcall', 'ntoskrnl.SeQuerySecurityDescriptorInfo', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.sequerysessionidtoken':( 'int', None, 'stdcall', 'ntoskrnl.SeQuerySessionIdToken', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.seregisterlogonsessionterminatedroutine':( 'int', None, 'stdcall', 'ntoskrnl.SeRegisterLogonSessionTerminatedRoutine', (('int', None),) ),
    'ntoskrnl.sereleasesecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.SeReleaseSecurityDescriptor', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.sereleasesubjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeReleaseSubjectContext', (('void *', 'ptr'),) ),
    'ntoskrnl.sesetaccessstategenericmapping':( 'int', None, 'stdcall', 'ntoskrnl.SeSetAccessStateGenericMapping', (('int', None), ('int', None)) ),
    'ntoskrnl.sesetsecuritydescriptorinfo':( 'int', None, 'stdcall', 'ntoskrnl.SeSetSecurityDescriptorInfo', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.sesetsecuritydescriptorinfoex':( 'int', None, 'stdcall', 'ntoskrnl.SeSetSecurityDescriptorInfoEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.sesingleprivilegecheck':( 'int', None, 'msfastcall', 'ntoskrnl.SeSinglePrivilegeCheck', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.sesystemdefaultdacl':( 'int', None, 'cdecl', 'ntoskrnl.SeSystemDefaultDacl', () ),
    'ntoskrnl.setokenimpersonationlevel':( 'int', None, 'stdcall', 'ntoskrnl.SeTokenImpersonationLevel', (('int', None),) ),
    'ntoskrnl.setokenisadmin':( 'int', None, 'stdcall', 'ntoskrnl.SeTokenIsAdmin', (('int', None),) ),
    'ntoskrnl.setokenisrestricted':( 'int', None, 'stdcall', 'ntoskrnl.SeTokenIsRestricted', (('int', None),) ),
    'ntoskrnl.setokeniswriterestricted':( 'int', None, 'stdcall', 'ntoskrnl.SeTokenIsWriteRestricted', (('int', None),) ),
    'ntoskrnl.setokenobjecttype':( 'int', None, 'cdecl', 'ntoskrnl.SeTokenObjectType', () ),
    'ntoskrnl.setokentype':( 'int', None, 'stdcall', 'ntoskrnl.SeTokenType', (('int', None),) ),
    'ntoskrnl.seunlocksubjectcontext':( 'int', None, 'stdcall', 'ntoskrnl.SeUnlockSubjectContext', (('void *', 'ptr'),) ),
    'ntoskrnl.seunregisterlogonsessionterminatedroutine':( 'int', None, 'stdcall', 'ntoskrnl.SeUnregisterLogonSessionTerminatedRoutine', (('int', None),) ),
    'ntoskrnl.sevalidsecuritydescriptor':( 'int', None, 'stdcall', 'ntoskrnl.SeValidSecurityDescriptor', (('int', None), ('int', None)) ),
    'ntoskrnl.versetconditionmask':( 'int', None, 'stdcall', 'ntoskrnl.VerSetConditionMask', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.vffaildevicenode':( 'int', None, 'cdecl', 'ntoskrnl.VfFailDeviceNode', (('void *', 'obj'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.vffaildriver':( 'int', None, 'cdecl', 'ntoskrnl.VfFailDriver', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.vffailsystembios':( 'int', None, 'cdecl', 'ntoskrnl.VfFailSystemBIOS', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.vfisverificationenabled':( 'int', None, 'stdcall', 'ntoskrnl.VfIsVerificationEnabled', (('int', None), ('void *', 'obj')) ),
    'ntoskrnl.write_register_buffer_uchar':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_BUFFER_UCHAR', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.write_register_buffer_ulong':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_BUFFER_ULONG', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.write_register_buffer_ushort':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_BUFFER_USHORT', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.write_register_uchar':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_UCHAR', (('int', None), ('int', None)) ),
    'ntoskrnl.write_register_ulong':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_ULONG', (('int', None), ('int', None)) ),
    'ntoskrnl.write_register_ushort':( 'int', None, 'stdcall', 'ntoskrnl.WRITE_REGISTER_USHORT', (('int', None), ('int', None)) ),
    'ntoskrnl.wmiflushtrace':( 'int', None, 'stdcall', 'ntoskrnl.WmiFlushTrace', (('void *', 'ptr'),) ),
    'ntoskrnl.wmigetclock':( 'int', None, 'cdecl', 'ntoskrnl.WmiGetClock', () ),
    'ntoskrnl.wmiquerytrace':( 'int', None, 'stdcall', 'ntoskrnl.WmiQueryTrace', (('void *', 'ptr'),) ),
    'ntoskrnl.wmiquerytraceinformation':( 'int', None, 'stdcall', 'ntoskrnl.WmiQueryTraceInformation', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.wmistarttrace':( 'int', None, 'stdcall', 'ntoskrnl.WmiStartTrace', (('void *', 'ptr'),) ),
    'ntoskrnl.wmistoptrace':( 'int', None, 'stdcall', 'ntoskrnl.WmiStopTrace', (('void *', 'ptr'),) ),
    'ntoskrnl.wmitracemessage':( 'int', None, 'cdecl', 'ntoskrnl.WmiTraceMessage', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.wmitracemessageva':( 'int', None, 'stdcall', 'ntoskrnl.WmiTraceMessageVa', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.wmiupdatetrace':( 'int', None, 'stdcall', 'ntoskrnl.WmiUpdateTrace', (('void *', 'ptr'),) ),
    'ntoskrnl.xipdispatch':( 'int', None, 'stdcall', 'ntoskrnl.XIPDispatch', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwaccesscheckandauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.ZwAccessCheckAndAuditAlarm', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwaddbootentry':( 'int', None, 'stdcall', 'ntoskrnl.ZwAddBootEntry', (('int', None), ('int', None)) ),
    'ntoskrnl.zwadjustprivilegestoken':( 'int', None, 'stdcall', 'ntoskrnl.ZwAdjustPrivilegesToken', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwalertthread':( 'int', None, 'stdcall', 'ntoskrnl.ZwAlertThread', (('int', None),) ),
    'ntoskrnl.zwallocatevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.ZwAllocateVirtualMemory', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwassignprocesstojobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwAssignProcessToJobObject', (('int', None), ('int', None)) ),
    'ntoskrnl.zwcanceliofile':( 'int', None, 'stdcall', 'ntoskrnl.ZwCancelIoFile', (('int', None), ('int', None)) ),
    'ntoskrnl.zwcanceltimer':( 'int', None, 'stdcall', 'ntoskrnl.ZwCancelTimer', (('int', None), ('int', None)) ),
    'ntoskrnl.zwclearevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwClearEvent', (('int', None),) ),
    'ntoskrnl.zwclose':( 'int', None, 'stdcall', 'ntoskrnl.ZwClose', (('int', None),) ),
    'ntoskrnl.zwcloseobjectauditalarm':( 'int', None, 'stdcall', 'ntoskrnl.ZwCloseObjectAuditAlarm', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwconnectport':( 'int', None, 'stdcall', 'ntoskrnl.ZwConnectPort', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.zwcreatedirectoryobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateDirectoryObject', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwcreateevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateEvent', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwcreatefile':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateFile', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwcreatejobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateJobObject', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwcreatekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateKey', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwcreatesection':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateSection', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwcreatesymboliclinkobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateSymbolicLinkObject', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.zwcreatetimer':( 'int', None, 'stdcall', 'ntoskrnl.ZwCreateTimer', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwdeletebootentry':( 'int', None, 'stdcall', 'ntoskrnl.ZwDeleteBootEntry', (('int', None),) ),
    'ntoskrnl.zwdeletefile':( 'int', None, 'stdcall', 'ntoskrnl.ZwDeleteFile', (('void *', 'ptr'),) ),
    'ntoskrnl.zwdeletekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwDeleteKey', (('void *', 'ptr'),) ),
    'ntoskrnl.zwdeletevaluekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwDeleteValueKey', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwdeviceiocontrolfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwDeviceIoControlFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwdisplaystring':( 'int', None, 'stdcall', 'ntoskrnl.ZwDisplayString', (('int', None),) ),
    'ntoskrnl.zwduplicateobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwDuplicateObject', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwduplicatetoken':( 'int', None, 'stdcall', 'ntoskrnl.ZwDuplicateToken', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwenumeratebootentries':( 'int', None, 'stdcall', 'ntoskrnl.ZwEnumerateBootEntries', (('int', None), ('int', None)) ),
    'ntoskrnl.zwenumeratekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwEnumerateKey', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwenumeratevaluekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwEnumerateValueKey', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwflushinstructioncache':( 'int', None, 'stdcall', 'ntoskrnl.ZwFlushInstructionCache', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwflushkey':( 'int', None, 'stdcall', 'ntoskrnl.ZwFlushKey', (('int', None),) ),
    'ntoskrnl.zwflushvirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.ZwFlushVirtualMemory', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwfreevirtualmemory':( 'int', None, 'stdcall', 'ntoskrnl.ZwFreeVirtualMemory', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwfscontrolfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwFsControlFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwinitiatepoweraction':( 'int', None, 'stdcall', 'ntoskrnl.ZwInitiatePowerAction', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwisprocessinjob':( 'int', None, 'stdcall', 'ntoskrnl.ZwIsProcessInJob', (('int', None), ('int', None)) ),
    'ntoskrnl.zwloaddriver':( 'int', None, 'stdcall', 'ntoskrnl.ZwLoadDriver', (('void *', 'ptr'),) ),
    'ntoskrnl.zwloadkey':( 'int', None, 'stdcall', 'ntoskrnl.ZwLoadKey', (('int', None), ('int', None)) ),
    'ntoskrnl.zwmaketemporaryobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwMakeTemporaryObject', (('int', None),) ),
    'ntoskrnl.zwmapviewofsection':( 'int', None, 'stdcall', 'ntoskrnl.ZwMapViewOfSection', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwnotifychangekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwNotifyChangeKey', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopendirectoryobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenDirectoryObject', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopenevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenEvent', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopenfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenFile', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopenjobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenJobObject', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopenkey':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenKey', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopenprocess':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenProcess', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.zwopenprocesstoken':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenProcessToken', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopenprocesstokenex':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenProcessTokenEx', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopensection':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenSection', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopensymboliclinkobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenSymbolicLinkObject', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopenthread':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenThread', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopenthreadtoken':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenThreadToken', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwopenthreadtokenex':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenThreadTokenEx', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwopentimer':( 'int', None, 'stdcall', 'ntoskrnl.ZwOpenTimer', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwpowerinformation':( 'int', None, 'stdcall', 'ntoskrnl.ZwPowerInformation', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwpulseevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwPulseEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.zwquerybootentryorder':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryBootEntryOrder', (('int', None), ('int', None)) ),
    'ntoskrnl.zwquerybootoptions':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryBootOptions', (('int', None), ('int', None)) ),
    'ntoskrnl.zwquerydefaultlocale':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryDefaultLocale', (('int', None), ('int', None)) ),
    'ntoskrnl.zwquerydefaultuilanguage':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryDefaultUILanguage', (('int', None),) ),
    'ntoskrnl.zwquerydirectoryfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryDirectoryFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwquerydirectoryobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryDirectoryObject', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.zwqueryeafile':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryEaFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryfullattributesfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryFullAttributesFile', (('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInformationFile', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryinformationjobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInformationJobObject', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryinformationprocess':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInformationProcess', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryinformationthread':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInformationThread', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryinformationtoken':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInformationToken', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwqueryinstalluilanguage':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryInstallUILanguage', (('int', None),) ),
    'ntoskrnl.zwquerykey':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryKey', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwqueryobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryObject', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwquerysection':( 'int', None, 'stdcall', 'ntoskrnl.ZwQuerySection', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwquerysecurityobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwQuerySecurityObject', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwquerysymboliclinkobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwQuerySymbolicLinkObject', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwquerysysteminformation':( 'int', None, 'stdcall', 'ntoskrnl.ZwQuerySystemInformation', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwqueryvaluekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryValueKey', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwqueryvolumeinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwQueryVolumeInformationFile', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwreadfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwReadFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwreplacekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwReplaceKey', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwrequestwaitreplyport':( 'int', None, 'stdcall', 'ntoskrnl.ZwRequestWaitReplyPort', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.zwresetevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwResetEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.zwrestorekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwRestoreKey', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsavekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwSaveKey', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsavekeyex':( 'int', None, 'stdcall', 'ntoskrnl.ZwSaveKeyEx', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetbootentryorder':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetBootEntryOrder', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsetbootoptions':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetBootOptions', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsetdefaultlocale':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetDefaultLocale', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsetdefaultuilanguage':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetDefaultUILanguage', (('int', None),) ),
    'ntoskrnl.zwseteafile':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetEaFile', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetevent':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetEvent', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsetinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetInformationFile', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetinformationjobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetInformationJobObject', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetinformationobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetInformationObject', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwsetinformationprocess':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetInformationProcess', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetinformationthread':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetInformationThread', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetsecurityobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetSecurityObject', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwsetsysteminformation':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetSystemInformation', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwsetsystemtime':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetSystemTime', (('int', None), ('int', None)) ),
    'ntoskrnl.zwsettimer':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetTimer', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwsetvaluekey':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetValueKey', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwsetvolumeinformationfile':( 'int', None, 'stdcall', 'ntoskrnl.ZwSetVolumeInformationFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwterminatejobobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwTerminateJobObject', (('int', None), ('int', None)) ),
    'ntoskrnl.zwterminateprocess':( 'int', None, 'stdcall', 'ntoskrnl.ZwTerminateProcess', (('int', None), ('int', None)) ),
    'ntoskrnl.zwtranslatefilepath':( 'int', None, 'stdcall', 'ntoskrnl.ZwTranslateFilePath', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwunloaddriver':( 'int', None, 'stdcall', 'ntoskrnl.ZwUnloadDriver', (('void *', 'ptr'),) ),
    'ntoskrnl.zwunloadkey':( 'int', None, 'stdcall', 'ntoskrnl.ZwUnloadKey', (('int', None),) ),
    'ntoskrnl.zwunmapviewofsection':( 'int', None, 'stdcall', 'ntoskrnl.ZwUnmapViewOfSection', (('int', None), ('int', None)) ),
    'ntoskrnl.zwwaitformultipleobjects':( 'int', None, 'stdcall', 'ntoskrnl.ZwWaitForMultipleObjects', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.zwwaitforsingleobject':( 'int', None, 'stdcall', 'ntoskrnl.ZwWaitForSingleObject', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.zwwritefile':( 'int', None, 'stdcall', 'ntoskrnl.ZwWriteFile', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.zwyieldexecution':( 'int', None, 'cdecl', 'ntoskrnl.ZwYieldExecution', () ),
    'ntoskrnl._cicos':( 'int', None, 'cdecl', 'ntoskrnl._CIcos', () ),
    'ntoskrnl._cisin':( 'int', None, 'cdecl', 'ntoskrnl._CIsin', () ),
    'ntoskrnl._cisqrt':( 'int', None, 'cdecl', 'ntoskrnl._CIsqrt', () ),
    'ntoskrnl._abnormal_termination':( 'int', None, 'cdecl', 'ntoskrnl._abnormal_termination', () ),
    'ntoskrnl._alldiv':( 'int', None, 'stdcall', 'ntoskrnl._alldiv', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._alldvrm':( 'int', None, 'stdcall', 'ntoskrnl._alldvrm', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._allmul':( 'int', None, 'stdcall', 'ntoskrnl._allmul', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._alloca_probe':( 'int', None, 'cdecl', 'ntoskrnl._alloca_probe', () ),
    'ntoskrnl._allrem':( 'int', None, 'stdcall', 'ntoskrnl._allrem', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._allshl':( 'int', None, 'cdecl', 'ntoskrnl._allshl', () ),
    'ntoskrnl._allshr':( 'int', None, 'cdecl', 'ntoskrnl._allshr', () ),
    'ntoskrnl._aulldiv':( 'int', None, 'stdcall', 'ntoskrnl._aulldiv', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._aulldvrm':( 'int', None, 'stdcall', 'ntoskrnl._aulldvrm', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._aullrem':( 'int', None, 'stdcall', 'ntoskrnl._aullrem', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._aullshr':( 'int', None, 'cdecl', 'ntoskrnl._aullshr', () ),
    'ntoskrnl._except_handler2':( 'int', None, 'cdecl', 'ntoskrnl._except_handler2', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl._except_handler3':( 'int', None, 'cdecl', 'ntoskrnl._except_handler3', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl._global_unwind2':( 'int', None, 'cdecl', 'ntoskrnl._global_unwind2', (('int', None),) ),
    'ntoskrnl._itoa':( 'int', None, 'cdecl', 'ntoskrnl._itoa', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'ntoskrnl._itow':( 'int', None, 'cdecl', 'ntoskrnl._itow', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'ntoskrnl._local_unwind2':( 'int', None, 'cdecl', 'ntoskrnl._local_unwind2', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl._purecall':( 'int', None, 'cdecl', 'ntoskrnl._purecall', () ),
    'ntoskrnl._snprintf':( 'int', None, 'cdecl', 'ntoskrnl._snprintf', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'ntoskrnl._snwprintf':( 'int', None, 'cdecl', 'ntoskrnl._snwprintf', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl._stricmp':( 'int', None, 'cdecl', 'ntoskrnl._stricmp', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl._strlwr':( 'int', None, 'cdecl', 'ntoskrnl._strlwr', (('int', None),) ),
    'ntoskrnl._strnicmp':( 'int', None, 'cdecl', 'ntoskrnl._strnicmp', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._strnset':( 'int', None, 'cdecl', 'ntoskrnl._strnset', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._strrev':( 'int', None, 'cdecl', 'ntoskrnl._strrev', (('int', None),) ),
    'ntoskrnl._strset':( 'int', None, 'cdecl', 'ntoskrnl._strset', (('int', None), ('int', None)) ),
    'ntoskrnl._strupr':( 'int', None, 'cdecl', 'ntoskrnl._strupr', (('int', None),) ),
    'ntoskrnl._vsnprintf':( 'int', None, 'cdecl', 'ntoskrnl._vsnprintf', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._vsnwprintf':( 'int', None, 'cdecl', 'ntoskrnl._vsnwprintf', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._wcsicmp':( 'int', None, 'cdecl', 'ntoskrnl._wcsicmp', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl._wcslwr':( 'int', None, 'cdecl', 'ntoskrnl._wcslwr', (('int', None),) ),
    'ntoskrnl._wcsnicmp':( 'int', None, 'cdecl', 'ntoskrnl._wcsnicmp', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._wcsnset':( 'int', None, 'cdecl', 'ntoskrnl._wcsnset', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl._wcsrev':( 'int', None, 'cdecl', 'ntoskrnl._wcsrev', (('int', None),) ),
    'ntoskrnl._wcsupr':( 'int', None, 'cdecl', 'ntoskrnl._wcsupr', (('void *', 'ptr'),) ),
    'ntoskrnl.atoi':( 'int', None, 'cdecl', 'ntoskrnl.atoi', (('void *', 'ptr'),) ),
    'ntoskrnl.atol':( 'int', None, 'cdecl', 'ntoskrnl.atol', (('int', None),) ),
    'ntoskrnl.isdigit':( 'int', None, 'cdecl', 'ntoskrnl.isdigit', (('int', None),) ),
    'ntoskrnl.islower':( 'int', None, 'cdecl', 'ntoskrnl.islower', (('int', None),) ),
    'ntoskrnl.isprint':( 'int', None, 'cdecl', 'ntoskrnl.isprint', (('int', None),) ),
    'ntoskrnl.isspace':( 'int', None, 'cdecl', 'ntoskrnl.isspace', (('int', None),) ),
    'ntoskrnl.isupper':( 'int', None, 'cdecl', 'ntoskrnl.isupper', (('int', None),) ),
    'ntoskrnl.isxdigit':( 'int', None, 'cdecl', 'ntoskrnl.isxdigit', (('int', None),) ),
    'ntoskrnl.mbstowcs':( 'int', None, 'cdecl', 'ntoskrnl.mbstowcs', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.mbtowc':( 'int', None, 'cdecl', 'ntoskrnl.mbtowc', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.memchr':( 'int', None, 'cdecl', 'ntoskrnl.memchr', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.memcpy':( 'int', None, 'cdecl', 'ntoskrnl.memcpy', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.memmove':( 'int', None, 'cdecl', 'ntoskrnl.memmove', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.memset':( 'int', None, 'cdecl', 'ntoskrnl.memset', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.qsort':( 'int', None, 'thiscall', 'ntoskrnl.qsort', (('void *', 'obj'), ('void *', 'funcptr'), ('int', None), ('int', None), ('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.rand':( 'int', None, 'cdecl', 'ntoskrnl.rand', () ),
    'ntoskrnl.sprintf':( 'int', None, 'cdecl', 'ntoskrnl.sprintf', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.srand':( 'int', None, 'cdecl', 'ntoskrnl.srand', (('int', None),) ),
    'ntoskrnl.strcat':( 'int', None, 'cdecl', 'ntoskrnl.strcat', (('int', None), ('int', None)) ),
    'ntoskrnl.strchr':( 'int', None, 'cdecl', 'ntoskrnl.strchr', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.strcmp':( 'int', None, 'cdecl', 'ntoskrnl.strcmp', (('int', None), ('int', None)) ),
    'ntoskrnl.strcpy':( 'int', None, 'cdecl', 'ntoskrnl.strcpy', (('int', None), ('int', None)) ),
    'ntoskrnl.strlen':( 'int', None, 'cdecl', 'ntoskrnl.strlen', (('int', None),) ),
    'ntoskrnl.strncat':( 'int', None, 'cdecl', 'ntoskrnl.strncat', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.strncmp':( 'int', None, 'cdecl', 'ntoskrnl.strncmp', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.strncpy':( 'int', None, 'cdecl', 'ntoskrnl.strncpy', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'ntoskrnl.strrchr':( 'int', None, 'cdecl', 'ntoskrnl.strrchr', (('int', None), ('int', None)) ),
    'ntoskrnl.strspn':( 'int', None, 'cdecl', 'ntoskrnl.strspn', (('int', None), ('int', None)) ),
    'ntoskrnl.strstr':( 'int', None, 'cdecl', 'ntoskrnl.strstr', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.swprintf':( 'int', None, 'cdecl', 'ntoskrnl.swprintf', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.tolower':( 'int', None, 'cdecl', 'ntoskrnl.tolower', (('int', None),) ),
    'ntoskrnl.toupper':( 'int', None, 'cdecl', 'ntoskrnl.toupper', (('int', None),) ),
    'ntoskrnl.towlower':( 'int', None, 'cdecl', 'ntoskrnl.towlower', (('int', None),) ),
    'ntoskrnl.towupper':( 'int', None, 'cdecl', 'ntoskrnl.towupper', (('int', None),) ),
    'ntoskrnl.vdbgprintex':( 'int', None, 'stdcall', 'ntoskrnl.vDbgPrintEx', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.vdbgprintexwithprefix':( 'int', None, 'stdcall', 'ntoskrnl.vDbgPrintExWithPrefix', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.vsprintf':( 'int', None, 'cdecl', 'ntoskrnl.vsprintf', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.wcscat':( 'int', None, 'cdecl', 'ntoskrnl.wcscat', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.wcschr':( 'int', None, 'cdecl', 'ntoskrnl.wcschr', (('int', None), ('int', None)) ),
    'ntoskrnl.wcscmp':( 'int', None, 'cdecl', 'ntoskrnl.wcscmp', (('int', None), ('void *', 'ptr')) ),
    'ntoskrnl.wcscpy':( 'int', None, 'cdecl', 'ntoskrnl.wcscpy', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'ntoskrnl.wcscspn':( 'int', None, 'cdecl', 'ntoskrnl.wcscspn', (('int', None), ('int', None)) ),
    'ntoskrnl.wcslen':( 'int', None, 'cdecl', 'ntoskrnl.wcslen', (('void *', 'ptr'),) ),
    'ntoskrnl.wcsncat':( 'int', None, 'cdecl', 'ntoskrnl.wcsncat', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.wcsncmp':( 'int', None, 'cdecl', 'ntoskrnl.wcsncmp', (('int', None), ('int', None), ('int', None)) ),
    'ntoskrnl.wcsncpy':( 'int', None, 'cdecl', 'ntoskrnl.wcsncpy', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.wcsrchr':( 'int', None, 'cdecl', 'ntoskrnl.wcsrchr', (('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.wcsspn':( 'int', None, 'cdecl', 'ntoskrnl.wcsspn', (('int', None), ('int', None)) ),
    'ntoskrnl.wcsstr':( 'int', None, 'cdecl', 'ntoskrnl.wcsstr', (('int', None), ('int', None)) ),
    'ntoskrnl.wcstombs':( 'int', None, 'cdecl', 'ntoskrnl.wcstombs', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'ntoskrnl.wctomb':( 'int', None, 'cdecl', 'ntoskrnl.wctomb', (('void *', 'ptr'),) ),

}
